@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME                "bloom_filter_data"
-#define TB_TRACE_MODULE_DEBUG               (0)
+#define TB_TRACE_MODULE_NAME "bloom_filter_data"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -33,14 +33,13 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * implementation
  */
-tb_int_t xm_bloom_filter_data(lua_State* lua)
-{
-    // check
+tb_int_t xm_bloom_filter_data(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // is pointer?
-    if (!xm_lua_ispointer(lua, 1))
+    if (!xm_lua_ispointer(lua, 1)) {
         return 0;
+    }
 
     // get the bloom filter
     tb_bloom_filter_ref_t filter = (tb_bloom_filter_ref_t)xm_lua_topointer(lua, 1);
@@ -48,8 +47,10 @@ tb_int_t xm_bloom_filter_data(lua_State* lua)
 
     // get data
     tb_pointer_t data = (tb_pointer_t)tb_bloom_filter_data(filter);
-    if (data) xm_lua_pushpointer(lua, data);
-    else lua_pushnil(lua);
+    if (data) {
+        xm_lua_pushpointer(lua, data);
+    } else {
+        lua_pushnil(lua);
+    }
     return 1;
 }
-
