@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME                "fwatcher.wait"
-#define TB_TRACE_MODULE_DEBUG               (0)
+#define TB_TRACE_MODULE_NAME "fwatcher.wait"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -35,14 +35,13 @@
  */
 
 // fwatcher.wait(p)
-tb_int_t xm_fwatcher_wait(lua_State* lua)
-{
-    // check
+tb_int_t xm_fwatcher_wait(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // is pointer?
-    if (!xm_lua_ispointer(lua, 1))
+    if (!xm_lua_ispointer(lua, 1)) {
         return 0;
+    }
 
     // get the fwatcher
     tb_fwatcher_ref_t fwatcher = (tb_fwatcher_ref_t)xm_lua_topointer(lua, 1);
@@ -57,8 +56,7 @@ tb_int_t xm_fwatcher_wait(lua_State* lua)
 
     // save result
     lua_pushinteger(lua, ok);
-    if (ok > 0)
-    {
+    if (ok > 0) {
         lua_newtable(lua);
         lua_pushstring(lua, "path");
         lua_pushstring(lua, event.filepath);
