@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME                "sha"
-#define TB_TRACE_MODULE_DEBUG               (0)
+#define TB_TRACE_MODULE_NAME "sha"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -33,21 +33,17 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * implementation
  */
-tb_int_t xm_hash_sha(lua_State* lua)
-{
-    // check
+tb_int_t xm_hash_sha(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // get mode
     tb_size_t mode = (tb_size_t)lua_tointeger(lua, 1);
 
     // is bytes? get data and size
-    if (xm_lua_isinteger(lua, 2) && xm_lua_isinteger(lua, 3))
-    {
-        tb_byte_t const* data = (tb_byte_t const*)(tb_size_t)(tb_long_t)lua_tointeger(lua, 2);
+    if (xm_lua_isinteger(lua, 2) && xm_lua_isinteger(lua, 3)) {
+        tb_byte_t const *data = (tb_byte_t const *)(tb_size_t)(tb_long_t)lua_tointeger(lua, 2);
         tb_size_t size = (tb_size_t)lua_tointeger(lua, 3);
-        if (!data || !size)
-        {
+        if (!data || !size) {
             lua_pushnil(lua);
             lua_pushfstring(lua, "invalid data(%p) and size(%d)!", data, (tb_int_t)size);
             return 2;
@@ -72,33 +68,29 @@ tb_int_t xm_hash_sha(lua_State* lua)
     }
 
     // get the filename
-    tb_char_t const* filename = luaL_checkstring(lua, 2);
+    tb_char_t const *filename = luaL_checkstring(lua, 2);
     tb_check_return_val(filename, 0);
 
     // load data from file
     tb_bool_t ok = tb_false;
     tb_stream_ref_t stream = tb_stream_init_from_file(filename, TB_FILE_MODE_RO);
-    if (stream)
-    {
+    if (stream) {
         // open stream
-        if (tb_stream_open(stream))
-        {
+        if (tb_stream_open(stream)) {
             // init sha
             tb_sha_t sha;
             tb_sha_init(&sha, mode);
 
             // read data and update sha
             tb_byte_t data[TB_STREAM_BLOCK_MAXN];
-            while (!tb_stream_beof(stream))
-            {
+            while (!tb_stream_beof(stream)) {
                 // read data
                 tb_long_t real = tb_stream_read(stream, data, sizeof(data));
 
-                // ok?
-                if (real > 0) tb_sha_spak(&sha, data, real);
+                if (real > 0) {
+                    tb_sha_spak(&sha, data, real);
                 // no data? continue it
-                else if (!real)
-                {
+                } else if (!real) {
                     // wait
                     real = tb_stream_wait(stream, TB_STREAM_WAIT_READ, tb_stream_timeout(stream));
                     tb_check_break(real > 0);
@@ -107,7 +99,9 @@ tb_int_t xm_hash_sha(lua_State* lua)
                     tb_assert_and_check_break(real & TB_STREAM_WAIT_READ);
                 }
                 // failed or end?
-                else break;
+                else {
+                    break;
+                }
             }
 
             // exit sha
@@ -116,17 +110,19 @@ tb_int_t xm_hash_sha(lua_State* lua)
 
             // make sha string
             tb_char_t s[256];
-            tb_size_t n = sha.digest_len << 2;
+            tb_size_t n   = sha.digest_len << 2;
             tb_size_t len = xm_hash_make_cstr(s, buffer, n);
 
             // save result
-	        lua_pushlstring(lua, s, len);
+            lua_pushlstring(lua, s, len);
             ok = tb_true;
         }
 
         // exit stream
         tb_stream_exit(stream);
     }
-    if (!ok) lua_pushnil(lua);
+    if (!ok) {
+        lua_pushnil(lua);
+    }
     return 1;
 }
