@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME                "uuid4"
-#define TB_TRACE_MODULE_DEBUG               (0)
+#define TB_TRACE_MODULE_NAME "uuid4"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -33,16 +33,14 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * implementation
  */
-tb_int_t xm_hash_uuid4(lua_State* lua)
-{
-    // check
+tb_int_t xm_hash_uuid4(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // get the name
-    tb_char_t const* name = luaL_optstring(lua, 1, tb_null);
+    tb_char_t const *name = luaL_optstring(lua, 1, tb_null);
 
     // make uuid, use version 4
     tb_char_t uuid[37];
-	lua_pushstring(lua, tb_uuid4_make_cstr(uuid, name));
+    lua_pushstring(lua, tb_uuid4_make_cstr(uuid, name));
     return 1;
 }
