@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME    "pipe_close"
-#define TB_TRACE_MODULE_DEBUG   (0)
+#define TB_TRACE_MODULE_NAME "pipe_close"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -35,14 +35,13 @@
  */
 
 // io.pipe_close(pipe)
-tb_int_t xm_io_pipe_close(lua_State* lua)
-{
-    // check
+tb_int_t xm_io_pipe_close(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // check pipe?
-    if (!xm_pipe_file_is_valid(lua, 1))
+    if (!xm_pipe_file_is_valid(lua, 1)) {
         return 0;
+    }
 
     // get the pipe file
     tb_pipe_file_ref_t pipefile = xm_pipe_file_get(lua, 1);
@@ -52,4 +51,3 @@ tb_int_t xm_io_pipe_close(lua_State* lua)
     lua_pushboolean(lua, tb_pipe_file_exit(pipefile));
     return 1;
 }
-
