@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME    "socket_accept"
-#define TB_TRACE_MODULE_DEBUG   (0)
+#define TB_TRACE_MODULE_NAME "socket_accept"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -35,14 +35,13 @@
  */
 
 // local sock = io.socket_accept(sock)
-tb_int_t xm_io_socket_accept(lua_State* lua)
-{
-    // check
+tb_int_t xm_io_socket_accept(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // is pointer?
-    if (!xm_lua_ispointer(lua, 1))
+    if (!xm_lua_ispointer(lua, 1)) {
         return 0;
+    }
 
     // get socket
     tb_socket_ref_t sock = (tb_socket_ref_t)xm_lua_topointer(lua, 1);
@@ -50,8 +49,10 @@ tb_int_t xm_io_socket_accept(lua_State* lua)
 
     // accept socket
     tb_socket_ref_t client = tb_socket_accept(sock, tb_null);
-    if (client) xm_lua_pushpointer(lua, (tb_pointer_t)client);
-    else lua_pushnil(lua);
+    if (client) {
+        xm_lua_pushpointer(lua, (tb_pointer_t)client);
+    } else {
+        lua_pushnil(lua);
+    }
     return 1;
 }
-
