@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME    "socket_bind"
-#define TB_TRACE_MODULE_DEBUG   (0)
+#define TB_TRACE_MODULE_NAME "socket_bind"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -35,14 +35,11 @@
  */
 
 // io.socket_bind(sock, addr, port, family)
-tb_int_t xm_io_socket_bind(lua_State* lua)
-{
-    // check
+tb_int_t xm_io_socket_bind(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // check socket
-    if (!xm_lua_ispointer(lua, 1))
-    {
+    if (!xm_lua_ispointer(lua, 1)) {
         lua_pushboolean(lua, tb_false);
         lua_pushliteral(lua, "invalid socket!");
         return 2;
@@ -53,7 +50,7 @@ tb_int_t xm_io_socket_bind(lua_State* lua)
     tb_check_return_val(sock, 0);
 
     // get address
-    tb_char_t const* address = lua_tostring(lua, 2);
+    tb_char_t const *address = lua_tostring(lua, 2);
     tb_assert_and_check_return_val(address, 0);
 
     // get family
@@ -61,13 +58,10 @@ tb_int_t xm_io_socket_bind(lua_State* lua)
 
     // init address
     tb_ipaddr_t addr;
-    if (family == TB_IPADDR_FAMILY_UNIX)
-    {
+    if (family == TB_IPADDR_FAMILY_UNIX) {
         tb_bool_t is_abstract = (tb_bool_t)lua_toboolean(lua, 3);
         tb_ipaddr_unix_set_cstr(&addr, address, is_abstract);
-    }
-    else
-    {
+    } else {
         tb_uint16_t port = (tb_uint16_t)luaL_checknumber(lua, 3);
         tb_ipaddr_set(&addr, address, port, family);
     }
@@ -76,4 +70,3 @@ tb_int_t xm_io_socket_bind(lua_State* lua)
     lua_pushboolean(lua, tb_socket_bind(sock, &addr));
     return 1;
 }
-
