@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME    "socket_send"
-#define TB_TRACE_MODULE_DEBUG   (0)
+#define TB_TRACE_MODULE_NAME "socket_send"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -35,14 +35,11 @@
  */
 
 // io.socket_send(sock, data, start, last)
-tb_int_t xm_io_socket_send(lua_State* lua)
-{
-    // check
+tb_int_t xm_io_socket_send(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // check socket
-    if (!xm_lua_ispointer(lua, 1))
-    {
+    if (!xm_lua_ispointer(lua, 1)) {
         lua_pushinteger(lua, -1);
         lua_pushliteral(lua, "invalid socket!");
         return 2;
@@ -53,12 +50,15 @@ tb_int_t xm_io_socket_send(lua_State* lua)
     tb_check_return_val(sock, 0);
 
     // get data and size
-    tb_size_t        size = 0;
-    tb_byte_t const* data = tb_null;
-    if (xm_lua_isinteger(lua, 2)) data = (tb_byte_t const*)(tb_size_t)(tb_long_t)lua_tointeger(lua, 2);
-    if (xm_lua_isinteger(lua, 3)) size = (tb_size_t)lua_tointeger(lua, 3);
-    if (!data || !size)
-    {
+    tb_size_t size = 0;
+    tb_byte_t const *data = tb_null;
+    if (xm_lua_isinteger(lua, 2)) {
+        data = (tb_byte_t const *)(tb_size_t)(tb_long_t)lua_tointeger(lua, 2);
+    }
+    if (xm_lua_isinteger(lua, 3)) {
+        size = (tb_size_t)lua_tointeger(lua, 3);
+    }
+    if (!data || !size) {
         lua_pushinteger(lua, -1);
         lua_pushfstring(lua, "invalid data(%p) and size(%d)!", data, (tb_int_t)size);
         return 2;
