@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME    "strndup"
-#define TB_TRACE_MODULE_DEBUG   (0)
+#define TB_TRACE_MODULE_NAME "strndup"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -33,22 +33,23 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * implementation
  */
-tb_int_t xm_libc_strndup(lua_State* lua)
-{
-    // check
+tb_int_t xm_libc_strndup(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // do strndup
-    tb_char_t const* s = tb_null;
-    if (lua_isnumber(lua, 1))
-        s = (tb_char_t const*)(tb_size_t)lua_tointeger(lua, 1);
-    else if (lua_isstring(lua, 2))
+    tb_char_t const *s = tb_null;
+    if (lua_isnumber(lua, 1)) {
+        s = (tb_char_t const *)(tb_size_t)lua_tointeger(lua, 1);
+    } else if (lua_isstring(lua, 2)) {
         s = lua_tostring(lua, 2);
-    else xm_libc_return_error(lua, "libc.strndup(invalid args)!");
+    } else {
+        xm_libc_return_error(lua, "libc.strndup(invalid args)!");
+    }
     tb_int_t n = (tb_int_t)lua_tointeger(lua, 2);
-    if (s && n >= 0)
+    if (s && n >= 0) {
         lua_pushlstring(lua, s, n);
-    else lua_pushliteral(lua, "");
+    } else {
+        lua_pushliteral(lua, "");
+    }
     return 1;
 }
-
