@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME                "filesize"
-#define TB_TRACE_MODULE_DEBUG               (0)
+#define TB_TRACE_MODULE_NAME "filesize"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -33,19 +33,19 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * implementation
  */
-tb_int_t xm_os_filesize(lua_State* lua)
-{
-    // check
+tb_int_t xm_os_filesize(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // get the path
-    tb_char_t const* path = luaL_checkstring(lua, 1);
+    tb_char_t const *path = luaL_checkstring(lua, 1);
     tb_check_return_val(path, 0);
 
     // os.filesize(path)
-    tb_file_info_t info = {0};
-    if (tb_file_info(path, &info) && (info.type == TB_FILE_TYPE_FILE))
+    tb_file_info_t info = { 0 };
+    if (tb_file_info(path, &info) && (info.type == TB_FILE_TYPE_FILE)) {
         lua_pushinteger(lua, (lua_Integer)info.size);
-    else lua_pushinteger(lua, 0);
+    } else {
+        lua_pushinteger(lua, 0);
+    }
     return 1;
 }
