@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME                "link"
-#define TB_TRACE_MODULE_DEBUG               (0)
+#define TB_TRACE_MODULE_NAME "link"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -33,19 +33,16 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * implementation
  */
-tb_int_t xm_os_link(lua_State* lua)
-{
-    // check
+tb_int_t xm_os_link(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // get the source and destination
-    tb_char_t const* src = luaL_checkstring(lua, 1);
-    tb_char_t const* dst = luaL_checkstring(lua, 2);
+    tb_char_t const *src = luaL_checkstring(lua, 1);
+    tb_char_t const *dst = luaL_checkstring(lua, 2);
     tb_check_return_val(src && dst, 0);
 
     // do os.link(src, dst)
     lua_pushboolean(lua, tb_file_link(src, dst));
 
-    // ok
     return 1;
 }
