@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME                "mclock"
-#define TB_TRACE_MODULE_DEBUG               (0)
+#define TB_TRACE_MODULE_NAME "mclock"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -35,14 +35,11 @@
  */
 
 // os.mclock()
-tb_int_t xm_os_mclock(lua_State* lua)
-{
-    // check
+tb_int_t xm_os_mclock(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // save result
     lua_pushnumber(lua, (lua_Number)tb_mclock());
 
-    // ok
     return 1;
 }
