@@ -22,24 +22,25 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME                "signal"
-#define TB_TRACE_MODULE_DEBUG               (0)
+#define TB_TRACE_MODULE_NAME "signal"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
  */
 #include "prefix.h"
 #if defined(TB_CONFIG_OS_MACOSX) || defined(TB_CONFIG_OS_IOS)
-#   include <unistd.h>
-#   include <signal.h>
-#elif defined(TB_CONFIG_OS_LINUX) || defined(TB_CONFIG_OS_BSD) || defined(TB_CONFIG_OS_ANDROID) || defined(TB_CONFIG_OS_HAIKU)
-#   include <unistd.h>
-#   include <signal.h>
+#include <unistd.h>
+#include <signal.h>
+#elif defined(TB_CONFIG_OS_LINUX) || defined(TB_CONFIG_OS_BSD) || defined(TB_CONFIG_OS_ANDROID) ||                     \
+    defined(TB_CONFIG_OS_HAIKU)
+#include <unistd.h>
+#include <signal.h>
 #endif
 #ifdef TB_CONFIG_OS_BSD
-#   include <sys/types.h>
-#   include <sys/sysctl.h>
-#   include <signal.h>
+#include <sys/types.h>
+#include <sys/sysctl.h>
+#include <signal.h>
 #endif
 
 /* //////////////////////////////////////////////////////////////////////////////////////
@@ -47,29 +48,27 @@
  */
 typedef enum __xm_os_signal_e {
     XM_OS_SIGINT = 2
-}xm_os_signal_e;
+} xm_os_signal_e;
 
 typedef enum __xm_os_signal_handler_e {
     XM_OS_SIGFUN = 0,
     XM_OS_SIGDFL = 1,
     XM_OS_SIGIGN = 2,
-}xm_os_signal_handler_e;
+} xm_os_signal_handler_e;
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * globals
  */
-static lua_State* g_lua = tb_null;
+static lua_State *g_lua = tb_null;
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * private implementation
  */
-static tb_void_t xm_os_signal_handler_impl(tb_int_t signo)
-{
+static tb_void_t xm_os_signal_handler_impl(tb_int_t signo) {
     // do callback(signo)
-    lua_State* lua = g_lua;
-    if (lua)
-    {
-        tb_char_t name[64] = {0};
+    lua_State *lua = g_lua;
+    if (lua) {
+        tb_char_t name[64] = { 0 };
         tb_snprintf(name, sizeof(name), "_SIGNAL_HANDLER_%d", signo);
         lua_getglobal(lua, name);
         lua_pushinteger(lua, signo);
@@ -78,76 +77,72 @@ static tb_void_t xm_os_signal_handler_impl(tb_int_t signo)
 }
 
 #if defined(TB_CONFIG_OS_WINDOWS)
-static BOOL WINAPI xm_os_signal_handler(DWORD ctrl_type)
-{
-    if (ctrl_type == CTRL_C_EVENT)
+static BOOL WINAPI xm_os_signal_handler(DWORD ctrl_type) {
+    if (ctrl_type == CTRL_C_EVENT) {
         xm_os_signal_handler_impl(XM_OS_SIGINT);
+    }
     return TRUE;
 }
 #elif defined(SIGINT)
-static tb_void_t xm_os_signal_handler(tb_int_t signo_native)
-{
+static tb_void_t xm_os_signal_handler(tb_int_t signo_native) {
     tb_int_t signo = -1;
-    switch (signo_native)
-    {
+    switch (signo_native) {
     case SIGINT:
         signo = XM_OS_SIGINT;
         break;
     default:
         break;
     }
-    if (signo >= 0)
+    if (signo >= 0) {
         xm_os_signal_handler_impl(signo);
+    }
 }
 #endif
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * implementation
  */
-tb_int_t xm_os_signal(lua_State* lua)
-{
-    // check
+tb_int_t xm_os_signal(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
-    g_lua = lua;
+    g_lua            = lua;
     tb_int_t handler = XM_OS_SIGFUN;
 
     // check signal handler
-    if (lua_isnumber(lua, 2))
-        handler = (tb_int_t) luaL_checkinteger(lua, 2);
-    else if (!lua_isfunction(lua, 2))
+    if (lua_isnumber(lua, 2)) {
+        handler = (tb_int_t)luaL_checkinteger(lua, 2);
+    } else if (!lua_isfunction(lua, 2)) {
         return 0;
+    }
 
     // save signal handler
     tb_int_t signo = (tb_int_t)luaL_checkinteger(lua, 1);
-    if (handler == XM_OS_SIGFUN)
-    {
-        tb_char_t name[64] = {0};
+    if (handler == XM_OS_SIGFUN) {
+        tb_char_t name[64] = { 0 };
         tb_snprintf(name, sizeof(name), "_SIGNAL_HANDLER_%d", signo);
         lua_pushvalue(lua, 2);
         lua_setglobal(lua, name);
     }
 
 #if defined(TB_CONFIG_OS_WINDOWS)
-    if (signo != XM_OS_SIGINT)
+    if (signo != XM_OS_SIGINT) {
         return 0;
+    }
 
-    switch (handler)
-    {
-        case XM_OS_SIGFUN:
-            SetConsoleCtrlHandler(xm_os_signal_handler, TRUE);
-            break;
-        case XM_OS_SIGDFL:
-            SetConsoleCtrlHandler(NULL, FALSE);
-            break;
-        case XM_OS_SIGIGN:
-            SetConsoleCtrlHandler(NULL, TRUE);
-            break;
-        default:
-            break;
+    switch (handler) {
+    case XM_OS_SIGFUN:
+        SetConsoleCtrlHandler(xm_os_signal_handler, TRUE);
+        break;
+    case XM_OS_SIGDFL:
+        SetConsoleCtrlHandler(NULL, FALSE);
+        break;
+    case XM_OS_SIGIGN:
+        SetConsoleCtrlHandler(NULL, TRUE);
+        break;
+    default:
+        break;
     }
 #elif defined(SIGINT)
-    switch (signo)
-    {
+    switch (signo) {
     case XM_OS_SIGINT:
         signo = SIGINT;
         break;
@@ -155,19 +150,18 @@ tb_int_t xm_os_signal(lua_State* lua)
         return 0;
     }
 
-    switch (handler)
-    {
-        case XM_OS_SIGFUN:
-            signal(signo, xm_os_signal_handler);
-            break;
-        case XM_OS_SIGDFL:
-            signal(signo, SIG_DFL);
-            break;
-        case XM_OS_SIGIGN:
-            signal(signo, SIG_IGN);
-            break;
-        default:
-            break;
+    switch (handler) {
+    case XM_OS_SIGFUN:
+        signal(signo, xm_os_signal_handler);
+        break;
+    case XM_OS_SIGDFL:
+        signal(signo, SIG_DFL);
+        break;
+    case XM_OS_SIGIGN:
+        signal(signo, SIG_IGN);
+        break;
+    default:
+        break;
     }
 #endif
     return 0;
