@@ -22,16 +22,16 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME                "uid"
-#define TB_TRACE_MODULE_DEBUG               (0)
+#define TB_TRACE_MODULE_NAME "uid"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
  */
 #include "prefix.h"
 #ifndef TB_CONFIG_OS_WINDOWS
-#   include <unistd.h>
-#   include <errno.h>
+#include <unistd.h>
+#include <errno.h>
 #endif
 
 /* //////////////////////////////////////////////////////////////////////////////////////
@@ -40,25 +40,19 @@
 #ifndef TB_CONFIG_OS_WINDOWS
 
 // get & set uid
-tb_int_t xm_os_uid(lua_State* lua)
-{
-    // check
+tb_int_t xm_os_uid(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     tb_int_t ruidset = -1;
     tb_int_t euidset = -1;
-    tb_int_t argc = lua_gettop(lua);
-    if (argc == 1)
-    {
-        if (lua_istable(lua, 1))
-        {
+    tb_int_t argc    = lua_gettop(lua);
+    if (argc == 1) {
+        if (lua_istable(lua, 1)) {
             // os.uid({["ruid"] = ruid, ["euid"] = euid})
             lua_getfield(lua, 1, "ruid");
             lua_getfield(lua, 1, "euid");
-            if (!lua_isnil(lua, -1))
-            {
-                if (!lua_isnumber(lua, -1))
-                {
+            if (!lua_isnil(lua, -1)) {
+                if (!lua_isnumber(lua, -1)) {
                     lua_pushfstring(lua, "invalid field type(%s) in `euid` for os.uid", luaL_typename(lua, -1));
                     lua_error(lua);
                     return 0;
@@ -66,10 +60,8 @@ tb_int_t xm_os_uid(lua_State* lua)
                 euidset = (tb_int_t)lua_tonumber(lua, -1);
             }
             lua_pop(lua, 1);
-            if (!lua_isnil(lua, -1))
-            {
-                if (!lua_isnumber(lua, -1))
-                {
+            if (!lua_isnil(lua, -1)) {
+                if (!lua_isnumber(lua, -1)) {
                     lua_pushfstring(lua, "invalid field type(%s) in `ruid` for os.uid", luaL_typename(lua, -1));
                     lua_error(lua);
                     return 0;
@@ -77,45 +69,33 @@ tb_int_t xm_os_uid(lua_State* lua)
                 ruidset = (tb_int_t)lua_tonumber(lua, -1);
             }
             lua_pop(lua, 1);
-        }
-        else if (lua_isnumber(lua, 1))
-        {
+        } else if (lua_isnumber(lua, 1)) {
             // os.uid(uid)
             ruidset = euidset = (tb_int_t)lua_tonumber(lua, 1);
-        }
-        else
-        {
+        } else {
             lua_pushfstring(lua, "invalid argument type(%s) for os.uid", luaL_typename(lua, 1));
             lua_error(lua);
             return 0;
         }
-    }
-    else if (argc == 2)
-    {
+    } else if (argc == 2) {
         // os.uid(ruid, euid)
-        if (!lua_isnil(lua, 1))
-        {
-            if (!lua_isnumber(lua, 1))
-            {
+        if (!lua_isnil(lua, 1)) {
+            if (!lua_isnumber(lua, 1)) {
                 lua_pushfstring(lua, "invalid argument type(%s) for os.uid", luaL_typename(lua, 1));
                 lua_error(lua);
                 return 0;
             }
             ruidset = (tb_int_t)lua_tonumber(lua, 1);
         }
-        if (!lua_isnil(lua, 2))
-        {
-            if (!lua_isnumber(lua, 2))
-            {
+        if (!lua_isnil(lua, 2)) {
+            if (!lua_isnumber(lua, 2)) {
                 lua_pushfstring(lua, "invalid argument type(%s) for os.uid", luaL_typename(lua, 2));
                 lua_error(lua);
                 return 0;
             }
             euidset = (tb_int_t)lua_tonumber(lua, 2);
         }
-    }
-    else if (argc != 0)
-    {
+    } else if (argc != 0) {
         lua_pushstring(lua, "invalid argument count for os.uid");
         lua_error(lua);
         return 0;
@@ -124,8 +104,7 @@ tb_int_t xm_os_uid(lua_State* lua)
     // store return value
     lua_newtable(lua);
 
-    if (ruidset != -1 || euidset != -1)
-    {
+    if (ruidset != -1 || euidset != -1) {
         // set ruid & euid
         lua_pushstring(lua, "errno");
         lua_pushinteger(lua, setreuid(ruidset, euidset) != 0 ? errno : 0);
@@ -144,7 +123,6 @@ tb_int_t xm_os_uid(lua_State* lua)
     lua_pushinteger(lua, euid);
     lua_settable(lua, -3);
 
-    // ok
     return 1;
 }
 
