@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME                "history_list"
-#define TB_TRACE_MODULE_DEBUG               (0)
+#define TB_TRACE_MODULE_NAME "history_list"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -36,17 +36,14 @@
 #ifdef XM_CONFIG_API_HAVE_READLINE
 
 // history_list wrapper
-tb_int_t xm_readline_history_list(lua_State* lua)
-{
-    // check
+tb_int_t xm_readline_history_list(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // history list
     lua_newtable(lua);
 
 #ifdef TB_CONFIG_OS_MACOSX
-    for (tb_int_t i = 1; i <= history_length; ++i)
-    {
+    for (tb_int_t i = 1; i <= history_length; ++i) {
         lua_newtable(lua);
 
         // field line
@@ -59,8 +56,7 @@ tb_int_t xm_readline_history_list(lua_State* lua)
     }
 #else
     tb_int_t i = 1;
-    for (HIST_ENTRY **p = history_list(); *p; ++p, ++i)
-    {
+    for (HIST_ENTRY **p = history_list(); *p; ++p, ++i) {
         lua_newtable(lua);
 
         // field line
@@ -73,7 +69,6 @@ tb_int_t xm_readline_history_list(lua_State* lua)
     }
 #endif
 
-    // ok
     return 1;
 }
 
