@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME                "endswith"
-#define TB_TRACE_MODULE_DEBUG               (0)
+#define TB_TRACE_MODULE_NAME "endswith"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -33,21 +33,18 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * implementation
  */
-tb_int_t xm_string_endswith(lua_State* lua)
-{
-    // check
+tb_int_t xm_string_endswith(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // get the string and suffix
-    size_t              string_size = 0;
-    size_t              suffix_size = 0;
-    tb_char_t const*    string = luaL_checklstring(lua, 1, &string_size);
-    tb_char_t const*    suffix = luaL_checklstring(lua, 2, &suffix_size);
+    size_t string_size = 0;
+    size_t suffix_size = 0;
+    tb_char_t const *string = luaL_checklstring(lua, 1, &string_size);
+    tb_char_t const *suffix = luaL_checklstring(lua, 2, &suffix_size);
     tb_check_return_val(string && suffix, 0);
 
     // string:endswith(suffix)?
     lua_pushboolean(lua, string_size >= suffix_size && !tb_strcmp(string + string_size - suffix_size, suffix));
 
-    // ok
     return 1;
 }
