@@ -15,15 +15,15 @@
  * Copyright (C) 2015-present, Xmake Open Source Community.
  *
  * @author      ruki
- * @file        thread_event_incref.c
+ * @file        event_incref.c
  *
  */
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME                "thread_event"
-#define TB_TRACE_MODULE_DEBUG               (0)
+#define TB_TRACE_MODULE_NAME "thread_event"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -33,14 +33,12 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * implementation
  */
-tb_int_t xm_thread_event_incref(lua_State* lua)
-{
+tb_int_t xm_thread_event_incref(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
-    xm_thread_event_t* thread_event = xm_thread_event_get(lua, 1);
+    xm_thread_event_t *thread_event = xm_thread_event_get(lua, 1);
     tb_assert_and_check_return_val(thread_event && thread_event->handle, 0);
 
     lua_pushboolean(lua, tb_atomic_fetch_and_add(&thread_event->refn, 1) >= 1);
     return 1;
 }
-
