@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        xmake.lua
@@ -244,7 +244,8 @@ task("config")
                     {nil, "tryconfigs", "kv", nil       ,   "Set the extra configurations of the third-party buildsystem for the try-build mode.",
                                                             "e.g.",
                                                             "    - xmake f --trybuild=autoconf --tryconfigs='--enable-shared=no'"},
-                    {'o', "buildir",    "kv", "build"   , "Set build directory."},
+                    {'o', "builddir",   "kv", "build"   , "Set build directory."},
+                    {nil, "buildir",    "kv", nil       , "Set build directory. (deprecated)"},
                     {},
                     {category = "Project Configuration"},
                     _project_menu_options}}
