@@ -31,6 +31,7 @@ import("private.action.run.runenvs")
 import("private.service.remote_build.action", {alias = "remote_build_action"})
 import("private.detect.check_targetname")
 import("lib.detect.find_tool")
+import("private.action.utils", {alias = "action_utils"})
 
 -- run target
 function _do_run_target(target)
@@ -197,19 +198,13 @@ function main()
         -- to avoid trigger recheck configs
         config.clear()
         task.run("build", {target = option.get("target"), all = option.get("all")}, {disable_dump = true})
+    else
+        -- it will call on_config, we need to avoid repeat call it when autobuild is enabled.
+        project.load_targets()
     end
 
-    -- load targets
-    project.load_targets()
-
     -- check targets first
-    local targetname
-    local group_pattern = option.get("group")
-    if group_pattern then
-        group_pattern = "^" .. path.pattern(group_pattern) .. "$"
-    else
-        targetname = option.get("target")
-    end
+    local targetname, group_pattern = action_utils.get_target_and_group()
     _check_targets(targetname, group_pattern)
 
     -- enter project directory
