@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        interpreter.lua
@@ -770,7 +770,8 @@ function interpreter:load(file, opt)
     self:_clear()
 
     -- translate to absolute file path for scriptdir/rootdir
-    file = path.absolute(file)
+    -- we need to normalize path for rootdir, @see https://github.com/xmake-io/xmake/issues/6995
+    file = path.normalize(path.absolute(file))
 
     -- init the current file
     self._PRIVATE._CURFILE = file
@@ -1793,7 +1794,7 @@ function interpreter:api_builtin_includes(...)
                 files = os.files(subpath)
             else
                 -- @see https://github.com/xmake-io/xmake/issues/6026
-                files = os.files(path.join(subpath, path.filename(curfile)))
+                files = os.files(path.join(subpath, "xmake.lua"))
             end
             if files and #files > 0 then
                 table.join2(subpaths_matched, files)
@@ -1865,11 +1866,8 @@ function interpreter:api_builtin_includes(...)
                 -- clear the current scope, force to enter root scope
                 scopes._CURRENT = nil
 
-                -- save the current directory
-                local oldir = os.curdir()
-
                 -- enter the script directory
-                os.cd(path.directory(file))
+                local oldir = os.cd(path.directory(file))
 
                 -- done interpreter
                 local ok, errors = xpcall(script, interpreter._traceback)
