@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        platform.lua
@@ -281,7 +281,7 @@ function _instance:check()
                 standalone = true
             end
             idx = idx + 1
-            table.insert(toolchains_valid, toolchain:name())
+            table.insert(toolchains_valid, toolchain:fullname())
         end
     end
     if #toolchains == 0 then
