@@ -40,21 +40,30 @@ local sandbox        = require("sandbox/sandbox")
 local sandbox_module = require("sandbox/modules/import/core/sandbox/module")
 
 -- new an instance
-function _instance.new(name, info, cachekey, is_builtin, configs)
-    local instance       = table.inherit(_instance)
+function _instance.new(name, info, opt)
+    opt = opt or {}
+    local cachekey = opt.cachekey
+    local configs = opt.configs
+    local instance = table.inherit(_instance)
     local parts = name:split("::", {plain = true})
     instance._NAME = parts[#parts]
     table.remove(parts)
     if #parts > 0 then
         instance._NAMESPACE = table.concat(parts, "::")
     end
-    instance._INFO       = info
-    instance._IS_BUILTIN = is_builtin
-    instance._CACHE      = toolchain._localcache()
-    instance._CACHEKEY   = cachekey
-    instance._CONFIGS    = instance._CACHE:get(cachekey) or {}
+    instance._INFO          = info
+    instance._REQUIRESTR    = opt.requirestr
+    instance._IS_BUILTIN    = opt.is_builtin
+    instance._CACHE         = toolchain._localcache()
+    instance._CACHEKEY      = cachekey
+    local toolchain_configs = instance._CACHE:get(cachekey)
+    if toolchain_configs == nil then
+        toolchain_configs = {}
+        instance._CACHE:set(cachekey, toolchain_configs)
+    end
+    instance._CONFIGS = toolchain_configs
     for k, v in pairs(configs) do
-        instance._CONFIGS[k] = v
+        toolchain_configs[k] = v
     end
     -- is global toolchain for the whole platform?
     configs.plat = nil
@@ -63,7 +72,7 @@ function _instance.new(name, info, cachekey, is_builtin, configs)
     local plat = config.get("plat") or os.host()
     local arch = config.get("arch") or os.arch()
     if instance:is_plat(plat) and instance:is_arch(arch) and #table.keys(configs) == 0 then
-        instance._CONFIGS.__global = true
+        toolchain_configs.__global = true
     end
     return instance
 end
@@ -81,7 +90,12 @@ end
 -- get the full name
 function _instance:fullname()
     local namespace = self:namespace()
-    return namespace and namespace .. "::" .. self:name() or self:name()
+    local name = self:name()
+    local requirestr = self._REQUIRESTR
+    if requirestr then
+        name = name .. "[" .. requirestr .. "]"
+    end
+    return namespace and namespace .. "::" .. name or name
 end
 
 -- get toolchain platform
@@ -281,10 +295,9 @@ function _instance:config_set(name, data)
     self._CONFIGS[name] = data
 end
 
--- save user configs
+-- save user config (deprecated)
 function _instance:configs_save()
-    self._CACHE:set(self:cachekey(), self._CONFIGS)
-    self._CACHE:save()
+    utils.warning("toolchain:configs_save() is deprecated, please remove it.")
 end
 
 -- do check, we only check it once for all architectures
@@ -305,7 +318,6 @@ function _instance:check()
         -- we need to persist this state
         checked = checked or false
         self:config_set("__checked", checked)
-        self:configs_save()
     end
     return checked
 end
@@ -430,6 +442,7 @@ function _instance:_description(toolkind)
             sc         = "the swift compiler",
             scld       = "the swift linker",
             scsh       = "the swift shared library linker",
+            scar       = "the swift static library archiver",
             gc         = "the golang compiler",
             gcld       = "the golang linker",
             gcar       = "the golang static library archiver",
@@ -589,11 +602,19 @@ function toolchain._cachekey(name, opt)
     return cachekey
 end
 
--- parse toolchain and package name
+-- parse toolchain, configs and package name
 --
--- format: toolchain@package
+-- formats:
+--
+-- 1. only toolchain name
+-- e.g. clang, gcc
+--
+-- 2. toolchain@package
 -- e.g. "clang@llvm-10", "@muslcc", zig
 --
+-- 3. toolchain[configs]@package
+-- e.g. "mingw[clang]@llvm-mingw", "msvc[vs=2025,..]"
+--
 function toolchain.parsename(name)
     local splitinfo = name:split('@', {plain = true, strict = true})
     local toolchain_name = splitinfo[1]
@@ -604,7 +625,34 @@ function toolchain.parsename(name)
     if packages == "" then
         packages = nil
     end
-    return toolchain_name or packages, packages
+    local requireconfs, requirestr
+    if toolchain_name then
+        local toolchain_name_raw, configs_str = toolchain_name:match("(.-)%[(.*)%]")
+        if toolchain_name_raw and configs_str then
+            configs_str = configs_str:gsub("%[(.*)%]", function (w)
+                return w:replace(",", ":")
+            end)
+            requirestr = configs_str
+            toolchain_name = toolchain_name_raw
+            local splitinfo = configs_str:split(",", {plain = true})
+            for _, v in ipairs(splitinfo) do
+                local parts = v:split("=", {plain = true})
+                local k = parts[1]
+                v = parts[2]
+                requireconfs = requireconfs or {}
+                if v then
+                    if v:find(":", 1 ,true) then
+                        requireconfs[k] = v:split(":", {plain = true})
+                    else
+                        requireconfs[k] = option.boolean(v)
+                    end
+                else
+                    requireconfs[k] = true
+                end
+            end
+        end
+    end
+    return {name = toolchain_name or packages, packages = packages, requireconfs = requireconfs, requirestr = requirestr}
 end
 
 -- get toolchain apis
@@ -660,18 +708,22 @@ end
 
 -- load toolchain
 function toolchain.load(name, opt)
-
-    -- get toolchain name and packages
     opt = opt or {}
-    local packages
-    name, packages = toolchain.parsename(name)
-    opt.packages = opt.packages or packages
+
+    -- parse toolchain name
+    local parseinfo = toolchain.parsename(name)
+    name = parseinfo.name
+
+    -- init configs
+    local configs = parseinfo.requireconfs or {}
+    table.join2(configs, opt)
+    configs.packages = opt.packages or parseinfo.packages
+    configs.plat = opt.plat or config.get("plat") or os.host()
+    configs.arch = opt.arch or config.get("arch") or os.arch()
 
     -- get cache
-    opt.plat = opt.plat or config.get("plat") or os.host()
-    opt.arch = opt.arch or config.get("arch") or os.arch()
     local cache = toolchain._memcache()
-    local cachekey = toolchain._cachekey(name, opt)
+    local cachekey = toolchain._cachekey(name, configs)
 
     -- get it directly from cache dirst
     local instance = cache:get(cachekey)
@@ -706,32 +758,37 @@ function toolchain.load(name, opt)
         return nil, errors
     end
 
-    -- check the toolchain name
-    local result = results[name]
-    if not result then
+    -- get toolchain info
+    local info = results[name]
+    if not info then
         return nil, string.format("the toolchain %s not found!", name)
     end
 
     -- save instance to the cache
-    instance = _instance.new(name, result, cachekey, true, opt)
+    instance = _instance.new(name, info, {cachekey = cachekey,
+        is_builtin = true, configs = configs, requirestr = parseinfo.requirestr})
     cache:set(cachekey, instance)
     return instance
 end
 
 -- load toolchain from the give toolchain info
 function toolchain.load_withinfo(name, info, opt)
-
-    -- get toolchain name and packages
     opt = opt or {}
-    local packages
-    name, packages = toolchain.parsename(name)
-    opt.packages = opt.packages or packages
+
+    -- parse toolchain name
+    local parseinfo = toolchain.parsename(name)
+    name = parseinfo.name
+
+    -- init configs
+    local configs = parseinfo.requireconfs or {}
+    table.join2(configs, opt)
+    configs.packages = opt.packages or parseinfo.packages
+    configs.plat = opt.plat or config.get("plat") or os.host()
+    configs.arch = opt.arch or config.get("arch") or os.arch()
 
     -- get cache key
-    opt.plat = opt.plat or config.get("plat") or os.host()
-    opt.arch = opt.arch or config.get("arch") or os.arch()
     local cache = toolchain._memcache()
-    local cachekey = toolchain._cachekey(name, opt)
+    local cachekey = toolchain._cachekey(name, configs)
 
     -- get it directly from cache dirst
     local instance = cache:get(cachekey)
@@ -740,7 +797,8 @@ function toolchain.load_withinfo(name, info, opt)
     end
 
     -- save instance to the cache
-    instance = _instance.new(name, info, cachekey, false, opt)
+    instance = _instance.new(name, info, {cachekey = cachekey,
+        is_builtin = false, configs = configs, requirestr = parseinfo.requirestr})
     cache:set(cachekey, instance)
     return instance
 end
@@ -828,7 +886,6 @@ function toolchain.tool(toolchains, toolkind, opt)
         cache:set2(cachekey, "program", program)
         cache:set2(cachekey, "toolname", toolname)
         cache:set2(cachekey, "toolchain_info", toolchain_info)
-        cache:save()
     end
     return program, toolname, toolchain_info
 end
@@ -871,5 +928,13 @@ function toolchain.toolconfig(toolchains, name, opt)
     return toolconfig or nil
 end
 
+-- save all configs to the local cache
+--
+-- @see flushing localcache for each test is too slow,
+-- so we only flush the toolchain configuration cache once after the configuration is completed.
+function toolchain.save()
+    toolchain._localcache():save()
+end
+
 -- return module
 return toolchain
