@@ -18,8 +18,8 @@
 -- @file        zig_cc.lua
 --
 
--- inherit gcc
-inherit("gcc")
+-- inherit clang
+inherit("clang")
 
 -- make the strip flag
 function nf_strip(self, level)
