@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        autoconf.lua
@@ -20,10 +20,12 @@
 
 -- imports
 import("core.base.option")
+import("core.base.semver")
 import("core.project.config")
 import("core.tool.toolchain")
 import("core.cache.memcache")
 import("lib.detect.find_tool")
+import("devel.git")
 import("private.utils.toolchain", {alias = "toolchain_utils"})
 
 -- translate paths
@@ -86,18 +88,40 @@ function _memcache()
     return memcache.cache("package.tools.autoconf")
 end
 
+-- has flag ?
+function _has_flag(package, flag)
+    local flag_name = flag:gsub("-", "")
+    local has_flag = _memcache():get2(tostring(package), flag_name)
+    if has_flag == nil then
+        local result = try {function() return os.iorunv("./configure", {"--help"}, {shell = true}) end}
+        if result and result:find(flag, 1, true) then
+            has_flag = true
+        end
+        has_flag = has_flag or false
+        _memcache():set2(tostring(package), flag_name, has_flag)
+    end
+    return has_flag
+end
+
+
 -- has `--with-pic`?
 function _has_with_pic(package)
-    local has_with_pic = _memcache():get2(tostring(package), "with_pic")
-    if has_with_pic == nil then
-        local result = try {function() return os.iorunv("./configure", {"--help"}, {shell = true}) end}
-        if result and result:find("--with-pic", 1, true) then
-            has_with_pic = true
-        end
-        has_with_pic = has_with_pic or false
-        _memcache():set2(tostring(package), "with_pic", has_with_pic)
-    end
-    return has_with_pic
+    return _has_flag(package, "--with-pic")
+end
+
+-- has `--enable-debug`?
+function _has_enable_debug(package)
+    return _has_flag(package, "--enable-debug")
+end
+
+-- has `--enable-static` and `--enable-shared`?
+function _has_enable_kind(package)
+    return _has_flag(package, "--enable-static") and _has_flag(package, "--enable-shared")
+end
+
+-- has `--disable-static` and `--disable-shared`?
+function _has_disable_kind(package)
+    return _has_flag(package, "--disable-static") and _has_flag(package, "--disable-shared")
 end
 
 -- get configs
@@ -170,6 +194,21 @@ function _get_configs(package, configs)
         package:config("pic") ~= false and _has_with_pic(package) then
         table.insert(configs, "--with-pic")
     end
+    if package:is_debug() and _has_enable_debug(package) then
+        table.insert(configs, "--enable-debug")
+    end
+    if package:is_library() then
+        if _has_enable_kind(package) then
+            table.insert(configs, "--enable-shared=" .. (package:config("shared") and "yes" or "no"))
+            table.insert(configs, "--enable-static=" .. (package:config("shared") and "no" or "yes"))
+        elseif _has_disable_kind(package) then
+            if package:config("shared") then
+                table.insert(configs, "--disable-static")
+            else
+                table.insert(configs, "--disable-shared")
+            end
+        end
+    end
     return configs
 end
 
@@ -239,6 +278,99 @@ function _get_ldflags_from_packagedeps(package, opt)
     return result
 end
 
+-- @see https://github.com/xmake-io/xmake/pull/6963
+function _apply_libtool_patch_for_cross(package, opt)
+    if not package:is_cross() or not os.isfile("libtool") then
+        return
+    end
+
+    -- this patch is only needed for clang-based toolchains
+    if not package:has_tool("cxx", "clang", "clangxx", "zig_cc") then
+        return
+    end
+
+    -- detect the version of generated libtool script
+    local libtool = io.readfile("libtool")
+    local libtool_version = libtool:match("macro_version=(%d+%.%d+%.%d+)")
+    if option.get("verbose") then
+        if libtool_version then
+            cprint("${dim}> checking for generated libtool version ... ${color.success} %s", libtool_version)
+        else
+            wprint("generated libtool version cannot be detected, the patch for cross-compilation cannot be applied.")
+        end
+    end
+    if libtool_version then
+        libtool_version = semver.new(libtool_version)
+    else
+        return
+    end
+
+    if not libtool_version:at("2.4.3", "2.6.0") then
+        return
+    end
+
+    -- load and parse patch list
+    local patch_dir = path.join(os.programdir(), "scripts", "patches", "libtool")
+    local loaded_patch_versions = {}
+    for _, patch_file in ipairs(os.files(path.join(patch_dir, "*.patch"))) do
+        local patch_version = path.filename(patch_file):rtrim(".patch")
+        table.insert(loaded_patch_versions, semver.new(patch_version))
+    end
+    table.sort(loaded_patch_versions)
+
+    -- select the suitable patch
+    local suitable_patch_versions = {}
+    local last_patch_version = nil
+    for _, patch_version in ipairs(loaded_patch_versions) do
+        if last_patch_version then
+            if libtool_version:at(last_patch_version, patch_version) then
+                -- some distributions (such as archlinux) may package the dev
+                -- version of libtool, in which case the next version of the 
+                -- patch may be applicable.
+                table.insert(suitable_patch_versions, last_patch_version)
+                table.insert(suitable_patch_versions, patch_version)
+                break
+            end
+        else
+            if #loaded_patch_versions == 1 then
+                if libtool_version:ge(patch_version) then
+                    table.insert(suitable_patch_versions, patch_version)
+                end
+            end
+        end
+        last_patch_version = patch_version
+    end
+
+    -- try to apply the suitable patch
+    local succeed = false
+    for _, patch_version in ipairs(suitable_patch_versions) do
+        if option.get("verbose") then
+            cprint("${dim}> try applying the patch ... ${color.success} >= %s", patch_version)
+        end
+        local patch_file = path.join(patch_dir, patch_version:shortstr() .. ".patch")
+        local result = try {
+            function ()
+                os.cp("libtool", "__xmake_patched_libtool")
+                git.apply(patch_file)
+                os.mv("__xmake_patched_libtool", "libtool")
+                return true
+            end
+        }
+        if result then
+            succeed = true
+            break
+        end
+    end
+
+    if option.get("verbose") then
+        if succeed then
+            cprint("${dim}> libtool patch for cross-compilation applied successfully")
+        else
+            wprint("unable to apply libtool cross-compilation patches, your build files were not modified.")
+        end
+    end
+end
+
 -- get the build environments
 function buildenvs(package, opt)
     opt = opt or {}
@@ -362,7 +494,7 @@ function buildenvs(package, opt)
     end
     if ldflags or shflags then
         -- autoconf does not use SHFLAGS
-        envs.LDFLAGS   = table.concat(_translate_paths(table.join(ldflags or {}, shflags)), ' ')
+        envs.LDFLAGS   = table.concat(table.reverse_unique(_translate_paths(table.join(ldflags or {}, shflags))), ' ')
     end
 
     -- cross-compilation? pass the full build environments
@@ -409,10 +541,20 @@ function buildenvs(package, opt)
             name = name:gsub("clang$", "ld")
             name = name:gsub("clang%-%d+", "ld")
             name = name:gsub("gcc$", "ld")
-            name = name:gsub("gcc-%d+", "ld")
+            name = name:gsub("gcc%-%d+$", "ld")
             name = name:gsub("g%+%+$", "ld")
-            name = name:gsub("g%+%+%-%d+", "ld")
-            envs.LD = dir and path.join(dir, name) or name
+            name = name:gsub("g%+%+%-%d+$", "ld")
+            if dir and os.isfile(path.join(dir, name)) then
+                envs.LD = path.join(dir, name)
+            else
+                local ld = find_tool("ld")
+                if ld and path.filename(ld.program) == name then
+                    envs.LD = ld.program
+                end
+            end
+        end
+        if ld and package:has_tool("ld", "zig_cc") then
+            envs.LD = package:build_getenv("ld.lld")
         end
         -- we need use clang++ as cxx, autoconf will use it as linker
         -- https://github.com/xmake-io/xmake/issues/2170
@@ -434,6 +576,7 @@ function buildenvs(package, opt)
 
     if is_host("windows") then
         envs.CC       = _translate_windows_bin_path(envs.CC)
+        envs.CXX      = _translate_windows_bin_path(envs.CXX)
         envs.AS       = _translate_windows_bin_path(envs.AS)
         envs.AR       = _translate_windows_bin_path(envs.AR)
         envs.LD       = _translate_windows_bin_path(envs.LD)
@@ -536,6 +679,8 @@ function configure(package, configs, opt)
 
     -- do configure
     os.vrunv("./configure", argv, {shell = true, envs = envs})
+
+    _apply_libtool_patch_for_cross(package, opt)
 end
 
 -- do make
