@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        cmake.lua
@@ -227,7 +227,7 @@ function _get_cxxflags(package, opt)
     table.join2(result, package:config("cxxflags"))
     table.join2(result, package:config("cxflags"))
     if opt.cxxflags then
-        table.join2(result, opt.cflags)
+        table.join2(result, opt.cxxflags)
     end
     if opt.cxflags then
         table.join2(result, opt.cxflags)
@@ -315,6 +315,13 @@ function _get_shflags(package, opt)
     end
 end
 
+-- get arflags
+function _get_arflags(package, opt)
+    local result = table.wrap(package:build_getenv("arflags"))
+    if #result > 0 then
+        return os.args(_translate_paths(result))
+    end
+end
 -- get cmake version
 function _get_cmake_version()
     local cmake_version = _g.cmake_version
@@ -385,12 +392,20 @@ function _fix_cxx_compiler_cmake(package, envs)
     end
 end
 
+-- @see https://github.com/ziglang/zig/issues/22213
+function _fix_zigcc_linker_cmake(package, envs)
+    if package:has_tool("cc", "zig_cc") then
+        envs.CMAKE_C_LINKER_DEPFILE_SUPPORTED = "FALSE"
+        envs.CMAKE_CXX_LINKER_DEPFILE_SUPPORTED = "FALSE"
+    end
+end
+
 -- insert configs from envs
 function _insert_configs_from_envs(configs, envs, opt)
     opt = opt or {}
     local configs_str = opt._configs_str
     for k, v in pairs(envs) do
-        if configs_str and configs_str:find(k, 1, true) then
+        if configs_str and configs_str:find("-D" .. k .. "=", 1, true) then
             -- use user custom configuration
         else
             table.insert(configs, "-D" .. k .. "=" .. v)
@@ -400,37 +415,24 @@ end
 
 -- get configs for generic
 function _get_configs_for_generic(package, configs, opt)
-    local cflags = _get_cflags(package, opt)
-    if cflags then
-        table.insert(configs, "-DCMAKE_C_FLAGS=" .. cflags)
-    end
-    local cxxflags = _get_cxxflags(package, opt)
-    if cxxflags then
-        table.insert(configs, "-DCMAKE_CXX_FLAGS=" .. cxxflags)
-    end
-    local asflags = _get_asflags(package, opt)
-    if asflags then
-        table.insert(configs, "-DCMAKE_ASM_FLAGS=" .. asflags)
-    end
-    local ldflags = _get_ldflags(package, opt)
-    if ldflags then
-        table.insert(configs, "-DCMAKE_EXE_LINKER_FLAGS=" .. ldflags)
-    end
-    local shflags = _get_shflags(package, opt)
-    if shflags then
-        table.insert(configs, "-DCMAKE_SHARED_LINKER_FLAGS=" .. shflags)
-        table.insert(configs, "-DCMAKE_MODULE_LINKER_FLAGS=" .. shflags)
-    end
+    local envs = {}
     if not package:is_plat("windows", "mingw") and package:config("pic") ~= false then
-        table.insert(configs, "-DCMAKE_POSITION_INDEPENDENT_CODE=ON")
+        envs.CMAKE_POSITION_INDEPENDENT_CODE = "ON"
     end
     if not package:use_external_includes() then
-        table.insert(configs, "-DCMAKE_NO_SYSTEM_FROM_IMPORTED=ON")
+        envs.CMAKE_NO_SYSTEM_FROM_IMPORTED = "ON"
     end
+    envs.CMAKE_BUILD_TYPE = package:is_debug() and "Debug" or "Release"
+    if package:is_library() then
+        envs.BUILD_SHARED_LIBS = package:config("shared") and "ON" or "OFF"
+    end
+    _fix_zigcc_linker_cmake(package, envs)
+    _insert_configs_from_envs(configs, envs, opt)
 end
 
 -- get configs for windows
 function _get_configs_for_windows(package, configs, opt)
+    local envs = {}
     local cmake_generator = opt.cmake_generator
     if not cmake_generator or cmake_generator:find("Visual Studio", 1, true) then
         table.insert(configs, "-A")
@@ -447,43 +449,38 @@ function _get_configs_for_windows(package, configs, opt)
         end
         local vs_toolset = toolchain_utils.get_vs_toolset_ver(_get_msvc(package):config("vs_toolset") or config.get("vs_toolset"))
         if vs_toolset then
-            table.insert(configs, "-DCMAKE_GENERATOR_TOOLSET=" .. vs_toolset)
+            envs.CMAKE_GENERATOR_TOOLSET = vs_toolset
         end
     end
 
-    -- use clang-cl
-    if package:has_tool("cc", "clang_cl") then
-        table.insert(configs, "-DCMAKE_C_COMPILER=" .. _translate_bin_path(package:build_getenv("cc")))
+    -- use clang-cl or clang, and we need pass --target=xxx flags
+    if package:has_tool("cc", "clang", "clang_cl") then
+        envs.CMAKE_C_COMPILER = _translate_bin_path(package:build_getenv("cc"))
     end
-    if package:has_tool("cxx", "clang_cl") then
-        table.insert(configs, "-DCMAKE_CXX_COMPILER=" .. _translate_bin_path(package:build_getenv("cxx")))
+    if package:has_tool("cxx", "clang", "clang_cl") then
+        envs.CMAKE_CXX_COMPILER = _translate_bin_path(package:build_getenv("cxx"))
     end
 
     -- we maybe need patch `cmake_policy(SET CMP0091 NEW)` to enable this argument for some packages
     -- @see https://cmake.org/cmake/help/latest/policy/CMP0091.html#policy:CMP0091
     -- https://github.com/xmake-io/xmake-repo/pull/303
     if package:has_runtime("MT") then
-        table.insert(configs, "-DCMAKE_MSVC_RUNTIME_LIBRARY=MultiThreaded")
+        envs.CMAKE_MSVC_RUNTIME_LIBRARY = "MultiThreaded"
     elseif package:has_runtime("MTd") then
-        table.insert(configs, "-DCMAKE_MSVC_RUNTIME_LIBRARY=MultiThreadedDebug")
+        envs.CMAKE_MSVC_RUNTIME_LIBRARY = "MultiThreadedDebug"
     elseif package:has_runtime("MD") then
-        table.insert(configs, "-DCMAKE_MSVC_RUNTIME_LIBRARY=MultiThreadedDLL")
+        envs.CMAKE_MSVC_RUNTIME_LIBRARY = "MultiThreadedDLL"
     elseif package:has_runtime("MDd") then
-        table.insert(configs, "-DCMAKE_MSVC_RUNTIME_LIBRARY=MultiThreadedDebugDLL")
+        envs.CMAKE_MSVC_RUNTIME_LIBRARY = "MultiThreadedDebugDLL"
     end
 
     local pdb_dir = path.unix(path.join(os.curdir(), "pdb"))
-    if not opt._configs_str:find("CMAKE_COMPILE_PDB_OUTPUT_DIRECTORY", 1, true) then
-        table.insert(configs, "-DCMAKE_COMPILE_PDB_OUTPUT_DIRECTORY=" .. pdb_dir)
-    end
-    if not opt._configs_str:find("CMAKE_PDB_OUTPUT_DIRECTORY", 1, true) then
-        table.insert(configs, "-DCMAKE_PDB_OUTPUT_DIRECTORY=" .. pdb_dir)
-    end
+    envs.CMAKE_COMPILE_PDB_OUTPUT_DIRECTORY = pdb_dir
+    envs.CMAKE_PDB_OUTPUT_DIRECTORY = pdb_dir
+    _insert_configs_from_envs(configs, envs, opt)
 
     if package:is_cross() then
         _get_configs_for_cross(package, configs, opt)
-    else
-        _get_configs_for_generic(package, configs, opt)
     end
 end
 
@@ -520,7 +517,6 @@ function _get_configs_for_android(package, configs, opt)
         table.insert(configs, "-DCMAKE_FIND_ROOT_PATH_MODE_INCLUDE=BOTH")
         table.insert(configs, "-DCMAKE_FIND_ROOT_PATH_MODE_PROGRAM=NEVER")
     end
-    _get_configs_for_generic(package, configs, opt)
 end
 
 -- get configs for appleos
@@ -528,13 +524,6 @@ function _get_configs_for_appleos(package, configs, opt)
     opt = opt or {}
     local envs                     = {}
     opt.cross                      = true
-    envs.CMAKE_C_FLAGS             = _get_cflags(package, opt)
-    envs.CMAKE_CXX_FLAGS           = _get_cxxflags(package, opt)
-    envs.CMAKE_ASM_FLAGS           = _get_asflags(package, opt)
-    envs.CMAKE_STATIC_LINKER_FLAGS = table.concat(table.wrap(package:build_getenv("arflags")), ' ')
-    envs.CMAKE_EXE_LINKER_FLAGS    = _get_ldflags(package, opt)
-    envs.CMAKE_SHARED_LINKER_FLAGS = _get_shflags(package, opt)
-    envs.CMAKE_MODULE_LINKER_FLAGS = _get_shflags(package, opt)
     -- https://cmake.org/cmake/help/v3.17/manual/cmake-toolchains.7.html#id25
     if package:is_plat("watchos") then
         envs.CMAKE_SYSTEM_NAME = "watchOS"
@@ -573,13 +562,6 @@ function _get_configs_for_mingw(package, configs, opt)
     envs.CMAKE_AR                  = _translate_bin_path(package:build_getenv("ar"))
     envs.CMAKE_RANLIB              = _translate_bin_path(package:build_getenv("ranlib"))
     envs.CMAKE_RC_COMPILER         = _translate_bin_path(package:build_getenv("mrc"))
-    envs.CMAKE_C_FLAGS             = _get_cflags(package, opt)
-    envs.CMAKE_CXX_FLAGS           = _get_cxxflags(package, opt)
-    envs.CMAKE_ASM_FLAGS           = _get_asflags(package, opt)
-    envs.CMAKE_STATIC_LINKER_FLAGS = table.concat(table.wrap(package:build_getenv("arflags")), ' ')
-    envs.CMAKE_EXE_LINKER_FLAGS    = _get_ldflags(package, opt)
-    envs.CMAKE_SHARED_LINKER_FLAGS = _get_shflags(package, opt)
-    envs.CMAKE_MODULE_LINKER_FLAGS = _get_shflags(package, opt)
     -- @see https://cmake.org/cmake/help/latest/variable/CMAKE_CROSSCOMPILING.html
     -- https://github.com/xmake-io/xmake/pull/5888
     if not is_host("windows") then
@@ -588,7 +570,10 @@ function _get_configs_for_mingw(package, configs, opt)
     envs.CMAKE_SYSTEM_PROCESSOR    = _get_cmake_system_processor(package)
     -- avoid find and add system include/library path
     -- @see https://github.com/xmake-io/xmake/issues/2037
-    envs.CMAKE_FIND_ROOT_PATH      = sdkdir
+    -- https://github.com/xmake-io/xmake/issues/6660
+    if sdkdir and sdkdir ~= "/usr" then
+        envs.CMAKE_FIND_ROOT_PATH = sdkdir
+    end
     envs.CMAKE_FIND_ROOT_PATH_MODE_PACKAGE = "BOTH"
     envs.CMAKE_FIND_ROOT_PATH_MODE_LIBRARY = "BOTH"
     envs.CMAKE_FIND_ROOT_PATH_MODE_INCLUDE = "BOTH"
@@ -630,7 +615,6 @@ function _get_configs_for_wasm(package, configs, opt)
     envs.CMAKE_FIND_ROOT_PATH_MODE_LIBRARY = "BOTH"
     envs.CMAKE_FIND_ROOT_PATH_MODE_INCLUDE = "BOTH"
     envs.CMAKE_FIND_ROOT_PATH_MODE_PROGRAM = "NEVER"
-    _get_configs_for_generic(package, configs, opt)
     _insert_configs_from_envs(configs, envs, opt)
 end
 
@@ -644,8 +628,11 @@ function _get_configs_for_cross(package, configs, opt)
     envs.CMAKE_CXX_COMPILER        = _translate_bin_path(package:build_getenv("cxx"))
     envs.CMAKE_ASM_COMPILER        = _translate_bin_path(package:build_getenv("as"))
     envs.CMAKE_AR                  = _translate_bin_path(package:build_getenv("ar"))
-    if package:is_plat("windows") and package:has_tool("cxx", "cl") then
-        envs.CMAKE_AR = path.join(path.directory(envs.CMAKE_CXX_COMPILER), "lib.exe")
+    if package:is_plat("windows") then
+        envs.CMAKE_RC_COMPILER = _translate_bin_path(package:build_getenv("mrc"))
+        if package:has_tool("cxx", "cl") then
+            envs.CMAKE_AR = path.join(path.directory(envs.CMAKE_CXX_COMPILER), "lib.exe")
+        end
     end
     _fix_cxx_compiler_cmake(package, envs)
     -- @note The link command line is set in Modules/CMake{C,CXX,Fortran}Information.cmake and defaults to using the compiler, not CMAKE_LINKER,
@@ -658,14 +645,7 @@ function _get_configs_for_cross(package, configs, opt)
     if package:has_tool("ld", "gxx", "clangxx") then
         envs.CMAKE_CXX_LINK_EXECUTABLE = ld .. " <FLAGS> <CMAKE_CXX_LINK_FLAGS> <LINK_FLAGS> <OBJECTS> -o <TARGET> <LINK_LIBRARIES>"
     end
-    envs.CMAKE_RANLIB              = _translate_bin_path(package:build_getenv("ranlib"))
-    envs.CMAKE_C_FLAGS             = _get_cflags(package, opt)
-    envs.CMAKE_CXX_FLAGS           = _get_cxxflags(package, opt)
-    envs.CMAKE_ASM_FLAGS           = _get_asflags(package, opt)
-    envs.CMAKE_STATIC_LINKER_FLAGS = table.concat(table.wrap(package:build_getenv("arflags")), ' ')
-    envs.CMAKE_EXE_LINKER_FLAGS    = _get_ldflags(package, opt)
-    envs.CMAKE_SHARED_LINKER_FLAGS = _get_shflags(package, opt)
-    envs.CMAKE_MODULE_LINKER_FLAGS = _get_shflags(package, opt)
+    envs.CMAKE_RANLIB = _translate_bin_path(package:build_getenv("ranlib"))
     -- we don't need to set it as cross compilation if we just pass toolchain
     -- https://github.com/xmake-io/xmake/issues/2170
     if package:is_cross() then
@@ -676,13 +656,14 @@ function _get_configs_for_cross(package, configs, opt)
             system_name = "Windows"
         end
         envs.CMAKE_SYSTEM_NAME = system_name
-    end
-    if not package:is_plat("windows", "mingw") and package:config("pic") ~= false then
-        table.insert(configs, "-DCMAKE_POSITION_INDEPENDENT_CODE=ON")
+        envs.CMAKE_SYSTEM_PROCESSOR = _get_cmake_system_processor(package)
     end
     -- avoid find and add system include/library path
     -- @see https://github.com/xmake-io/xmake/issues/2037
-    envs.CMAKE_FIND_ROOT_PATH              = sdkdir
+    -- https://github.com/xmake-io/xmake/issues/6660
+    if sdkdir and sdkdir ~= "/usr" then
+        envs.CMAKE_FIND_ROOT_PATH = sdkdir
+    end
     envs.CMAKE_FIND_ROOT_PATH_MODE_PACKAGE = "BOTH"
     envs.CMAKE_FIND_ROOT_PATH_MODE_LIBRARY = "BOTH"
     envs.CMAKE_FIND_ROOT_PATH_MODE_INCLUDE = "BOTH"
@@ -702,7 +683,6 @@ function _get_configs_for_host_toolchain(package, configs, opt)
     opt = opt or {}
     opt.cross                      = true
     local envs                     = {}
-    local sdkdir                   = _translate_paths(package:build_getenv("sdk"))
     envs.CMAKE_C_COMPILER          = _translate_bin_path(package:build_getenv("cc"))
     envs.CMAKE_CXX_COMPILER        = _translate_bin_path(package:build_getenv("cxx"))
     envs.CMAKE_ASM_COMPILER        = _translate_bin_path(package:build_getenv("as"))
@@ -719,41 +699,19 @@ function _get_configs_for_host_toolchain(package, configs, opt)
     if package:has_tool("ld", "gxx", "clangxx") then
         envs.CMAKE_CXX_LINK_EXECUTABLE = ld .. " <FLAGS> <CMAKE_CXX_LINK_FLAGS> <LINK_FLAGS> <OBJECTS> -o <TARGET> <LINK_LIBRARIES>"
     end
-    envs.CMAKE_RANLIB              = _translate_bin_path(package:build_getenv("ranlib"))
-    envs.CMAKE_C_FLAGS             = _get_cflags(package, opt)
-    envs.CMAKE_CXX_FLAGS           = _get_cxxflags(package, opt)
-    envs.CMAKE_ASM_FLAGS           = _get_asflags(package, opt)
-    envs.CMAKE_STATIC_LINKER_FLAGS = table.concat(table.wrap(package:build_getenv("arflags")), ' ')
-    envs.CMAKE_EXE_LINKER_FLAGS    = _get_ldflags(package, opt)
-    envs.CMAKE_SHARED_LINKER_FLAGS = _get_shflags(package, opt)
-    envs.CMAKE_MODULE_LINKER_FLAGS = _get_shflags(package, opt)
+    envs.CMAKE_RANLIB = _translate_bin_path(package:build_getenv("ranlib"))
     -- we don't need to set it as cross compilation if we just pass toolchain
     -- https://github.com/xmake-io/xmake/issues/2170
     if package:is_cross() then
         envs.CMAKE_SYSTEM_NAME     = "Linux"
     end
-    if not package:is_plat("windows", "mingw") and package:config("pic") ~= false then
-        table.insert(configs, "-DCMAKE_POSITION_INDEPENDENT_CODE=ON")
-    end
     _insert_configs_from_envs(configs, envs, opt)
 end
 
 -- get cmake generator for msvc
 function _get_cmake_generator_for_msvc(package)
-    local vsvers =
-    {
-        ["2022"] = "17",
-        ["2019"] = "16",
-        ["2017"] = "15",
-        ["2015"] = "14",
-        ["2013"] = "12",
-        ["2012"] = "11",
-        ["2010"] = "10",
-        ["2008"] = "9"
-    }
     local vs = _get_msvc(package):config("vs") or config.get("vs")
-    assert(vsvers[vs], "Unknown Visual Studio version: '" .. tostring(vs) .. "' set in project.")
-    return "Visual Studio " .. vsvers[vs] .. " " .. vs
+    return "Visual Studio " .. toolchain_utils.get_vsver(vs) .. " " .. vs
 end
 
 -- get configs for cmake generator
@@ -812,12 +770,23 @@ end
 function _get_default_flags(package, configs, buildtype, opt)
     -- The default flags are different for different platforms
     -- @see https://github.com/xmake-io/xmake-repo/pull/4038#issuecomment-2116489448
-    local cachekey = buildtype .. package:plat() .. package:arch()
+    local cc = package:build_getenv("cc")
+    local cxx = package:build_getenv("cxx")
+    local cachekey = buildtype .. package:plat() .. package:arch() .. (cc or "") .. (cxx or "")
     local cmake_default_flags = _g.cmake_default_flags and _g.cmake_default_flags[cachekey]
     if not cmake_default_flags then
         local tmpdir = path.join(os.tmpfile() .. ".dir", package:displayname(), package:mode())
         local dummy_cmakelist = path.join(tmpdir, "CMakeLists.txt")
 
+        local cflags
+        if cc then
+            cflags = "-DCMAKE_C_COMPILER=" .. _translate_bin_path(cc)
+        end
+        local cxxflags
+        if cxx then
+            cxxflags = "-DCMAKE_CXX_COMPILER=" .. _translate_bin_path(cxx)
+        end
+
         -- About the minimum cmake version requirement
         -- @see https://github.com/xmake-io/xmake/pull/6032
         io.writefile(dummy_cmakelist, format([[
@@ -842,21 +811,23 @@ function _get_default_flags(package, configs, buildtype, opt)
 
         local runenvs = opt.envs or buildenvs(package)
         local cmake = find_tool("cmake")
-        local _configs = table.join(configs, "-S " .. path.directory(dummy_cmakelist), "-B " .. tmpdir)
+        local _configs = table.join(configs, "-S", path.directory(dummy_cmakelist), "-B", tmpdir, cflags or {}, cxxflags)
         local outdata = try{ function() return os.iorunv(cmake.program, _configs, {envs = runenvs}) end}
-        if outdata then
+        if outdata and outdata ~= "" then
             cmake_default_flags = {}
-            cmake_default_flags.cflags = outdata:match("CMAKE_C_FLAGS is (.-)\n") or " "
-            cmake_default_flags.cflags = cmake_default_flags.cflags .. " " .. outdata:match(format("CMAKE_C_FLAGS_%s is (.-)\n", buildtype)):replace("/MDd", ""):replace("/MD", "")
-            cmake_default_flags.cxxflags = outdata:match("CMAKE_CXX_FLAGS is (.-)\n") or " "
-            cmake_default_flags.cxxflags = cmake_default_flags.cxxflags .. " " .. outdata:match(format("CMAKE_CXX_FLAGS_%s is (.-)\n", buildtype)):replace("/MDd", ""):replace("/MD", "")
-            cmake_default_flags.ldflags = outdata:match("CMAKE_EXE_LINKER_FLAGS is (.-)\n") or " "
-            cmake_default_flags.ldflags = cmake_default_flags.ldflags .. " " .. outdata:match(format("CMAKE_EXE_LINKER_FLAGS_%s is (.-)\n", buildtype))
-            cmake_default_flags.shflags = outdata:match("CMAKE_SHARED_LINKER_FLAGS is (.-)\n") or " "
-            cmake_default_flags.shflags = cmake_default_flags.shflags .. " " .. outdata:match(format("CMAKE_SHARED_LINKER_FLAGS_%s is (.-)\n", buildtype))
-            cmake_default_flags.arflags = outdata:match("CMAKE_STATIC_LINKER_FLAGS is (.-)\n") or " "
-            cmake_default_flags.arflags = cmake_default_flags.arflags .. " " ..outdata:match(format("CMAKE_STATIC_LINKER_FLAGS_%s is (.-)\n", buildtype))
-
+            cmake_default_flags.CMAKE_C_FLAGS = outdata:match("CMAKE_C_FLAGS is (.-)\n")
+            cmake_default_flags["CMAKE_C_FLAGS_" .. buildtype] = outdata:match(format("CMAKE_C_FLAGS_%s is (.-)\n", buildtype))
+            cmake_default_flags.CMAKE_CXX_FLAGS = outdata:match("CMAKE_CXX_FLAGS is (.-)\n")
+            cmake_default_flags["CMAKE_CXX_FLAGS_" .. buildtype] = outdata:match(format("CMAKE_CXX_FLAGS_%s is (.-)\n", buildtype))
+            cmake_default_flags.CMAKE_CXX_FLAGS = outdata:match("CMAKE_CXX_FLAGS is (.-)\n")
+            cmake_default_flags["CMAKE_EXE_LINKER_FLAGS_" .. buildtype] = outdata:match(format("CMAKE_EXE_LINKER_FLAGS_%s is (.-)\n", buildtype))
+            cmake_default_flags.CMAKE_SHARED_LINKER_FLAGS = outdata:match("CMAKE_SHARED_LINKER_FLAGS is (.-)\n")
+            cmake_default_flags["CMAKE_SHARED_LINKER_FLAGS_" .. buildtype] = outdata:match(format("CMAKE_SHARED_LINKER_FLAGS_%s is (.-)\n", buildtype))
+            cmake_default_flags.CMAKE_STATIC_LINKER_FLAGS = outdata:match("CMAKE_STATIC_LINKER_FLAGS is (.-)\n")
+            cmake_default_flags["CMAKE_STATIC_LINKER_FLAGS_" .. buildtype] = outdata:match(format("CMAKE_STATIC_LINKER_FLAGS_%s is (.-)\n", buildtype))
+            for k, v in ipairs(cmake_default_flags) do
+                cmake_default_flags[k] = v:replace("/M[DT]d", ""):replace("/M[DT]", "")
+            end
             _g.cmake_default_flags = _g.cmake_default_flags or {}
             _g.cmake_default_flags[cachekey] = cmake_default_flags
         end
@@ -877,29 +848,10 @@ end
 
 function _get_envs_for_default_flags(package, configs, opt)
     local buildtype = _get_cmake_buildtype(package)
-    local envs = {}
-    local default_flags = _get_default_flags(package, configs, buildtype, opt)
-    if default_flags then
-        if not opt.cxxflags and not opt.cxflags then
-            envs[format("CMAKE_CXX_FLAGS_%s", buildtype)] = default_flags.cxxflags
-        end
-        if not opt.cflags and not opt.cxflags then
-            envs[format("CMAKE_C_FLAGS_%s", buildtype)] = default_flags.cflags
-        end
-        if not opt.ldflags then
-            envs[format("CMAKE_EXE_LINKER_FLAGS_%s", buildtype)] = default_flags.ldflags
-        end
-        if not opt.arflags then
-            envs[format("CMAKE_STATIC_LINKER_FLAGS_%s", buildtype)] = default_flags.arflags
-        end
-        if not opt.shflags then
-            envs[format("CMAKE_SHARED_LINKER_FLAGS_%s", buildtype)] = default_flags.shflags
-        end
-    end
-    return envs
+    return table.clone(_get_default_flags(package, configs, buildtype, opt)) or {}
 end
 
-function _get_envs_for_runtime_flags(package, configs, opt)
+function _get_envs_for_runtime_flags(package, opt)
     local buildtype = _get_cmake_buildtype(package)
     local envs = {}
     local runtimes = package:runtimes()
@@ -914,11 +866,52 @@ function _get_envs_for_runtime_flags(package, configs, opt)
     return envs
 end
 
+function _get_envs_for_flags(package, configs, opt)
+    -- get the default envs
+    local envs = _get_envs_for_default_flags(package, configs, opt)
+    local runtime_envs = _get_envs_for_runtime_flags(package, opt)
+    if runtime_envs then
+        for name, value in pairs(runtime_envs) do
+            envs[name] = (envs[name] or " ") .. " " .. table.concat(value, " ")
+        end
+    end
+
+    -- get the platform/toolchain envs
+    local platform_envs = {}
+    if package:is_plat("windows") then
+        -- use clang-cl or clang, and we need pass --target=xxx flags
+        if package:has_tool("cc", "clang", "clang_cl") then
+            -- @see https://github.com/xmake-io/xmake-repo/issues/7662
+            platform_envs.CMAKE_C_FLAGS = _get_cflags(package, {cross = true, packagedeps = opt.packagedeps})
+        end
+        if package:has_tool("cxx", "clang", "clang_cl") then
+            platform_envs.CMAKE_CXX_FLAGS = _get_cxxflags(package, {cross = true, packagedeps = opt.packagedeps})
+        end
+    elseif package:is_plat("wasm") then
+        -- pass toolchain flags cross-compilation
+        -- @see https://github.com/xmake-io/xmake/issues/6690
+        opt.cross = true
+    end
+    platform_envs.CMAKE_C_FLAGS             = platform_envs.CMAKE_C_FLAGS or _get_cflags(package, opt)
+    platform_envs.CMAKE_CXX_FLAGS           = platform_envs.CMAKE_CXX_FLAGS or _get_cxxflags(package, opt)
+    platform_envs.CMAKE_ASM_FLAGS           = _get_asflags(package, opt)
+    platform_envs.CMAKE_EXE_LINKER_FLAGS    = _get_ldflags(package, opt)
+    platform_envs.CMAKE_SHARED_LINKER_FLAGS = _get_shflags(package, opt)
+    platform_envs.CMAKE_MODULE_LINKER_FLAGS = _get_shflags(package, opt)
+    platform_envs.CMAKE_STATIC_LINKER_FLAGS = _get_arflags(package, opt)
+    for name, value in pairs(platform_envs) do
+        envs[name] = (envs[name] or " ") .. " " .. value
+    end
+    return envs
+end
+
 function _get_configs(package, configs, opt)
     configs = configs or {}
     opt._configs_str = string.serialize(configs, {indent = false, strip = true})
     _get_configs_for_install(package, configs, opt)
     _get_configs_for_generator(package, configs, opt)
+    _get_configs_for_generic(package, configs, opt)
+
     if package:is_plat("windows") then
         _get_configs_for_windows(package, configs, opt)
     elseif package:is_plat("android") then
@@ -941,25 +934,27 @@ function _get_configs(package, configs, opt)
         else
             _get_configs_for_cross(package, configs, opt)
         end
-    else
-        _get_configs_for_generic(package, configs, opt)
     end
-    local envs = _get_envs_for_default_flags(package, configs, opt)
-    local runtime_envs = _get_envs_for_runtime_flags(package, configs, opt)
-    if runtime_envs then
-        envs = envs or {}
-        for name, value in pairs(runtime_envs) do
-            envs[name] = (envs[name] or " ") .. " " .. table.concat(value, " ")
-        end
-    end
-    _insert_configs_from_envs(configs, envs or {}, opt)
 
+    -- fix error for cmake 4.x
+    -- e.g. Compatibility with CMake < 3.5 has been removed from CMake.
+    if _get_cmake_version() and _get_cmake_version():ge("4.0") then
+        table.insert(configs, "-DCMAKE_POLICY_VERSION_MINIMUM=3.5")
+    end
+
+    -- insert flags to configs
+    --
+    -- @note We need to rely on configs to get the exact default flags
+    -- @see https://github.com/xmake-io/xmake/issues/6781
+    local envs = _get_envs_for_flags(package, configs, opt)
+    _insert_configs_from_envs(configs, envs, opt)
+
+    -- enable ccache?
     local ccache = package:data("ccache")
     if ccache then
         table.insert(configs, "-DCMAKE_C_COMPILER_LAUNCHER=" .. ccache)
         table.insert(configs, "-DCMAKE_CXX_COMPILER_LAUNCHER=" .. ccache)
     end
-
     return configs
 end
 
@@ -975,10 +970,13 @@ function _fix_pdbdir_for_ninja(package)
 end
 
 -- enter build directory
-function _enter_buildir(package, opt)
-    local buildir = opt.buildir or package:buildir()
-    os.mkdir(path.join(buildir, "install"))
-    return os.cd(buildir)
+function _enter_builddir(package, opt)
+    local builddir = opt.builddir or opt.buildir or package:builddir()
+    if opt.buildir then
+        wprint("{buildir = } has been deprecated, please use {builddir = } in cmake.install")
+    end
+    os.mkdir(path.join(builddir, "install"))
+    return os.cd(builddir)
 end
 
 -- get build environments
@@ -1044,7 +1042,7 @@ end
 -- do build for make
 function _build_for_make(package, configs, opt)
     local argv = {}
-    local targets = table.wrap(opt.target)
+    local targets = table.wrap(opt.targets or opt.target)
     if #targets ~= 0 then
         table.join2(argv, targets)
     end
@@ -1079,7 +1077,7 @@ function _build_for_ninja(package, configs, opt)
     _fix_pdbdir_for_ninja(package)
     ninja.build(package, {}, {envs = opt.envs or buildenvs(package, opt),
         jobs = opt.jobs,
-        target = opt.target})
+        targets = opt.targets or opt.target})
 end
 
 -- do build for cmake/build
@@ -1090,12 +1088,12 @@ function _build_for_cmakebuild(package, configs, opt)
         table.insert(argv, "--config")
         table.insert(argv, opt.config)
     end
-    local targets = table.wrap(opt.target)
+    local targets = table.wrap(opt.targets or opt.target)
     if #targets ~= 0 then
         table.insert(argv, "--target")
         if #targets > 1 then
             -- https://stackoverflow.com/questions/47553569/how-can-i-build-multiple-targets-using-cmake-build
-            if _get_cmake_version():ge("3.15") then
+            if _get_cmake_version() and _get_cmake_version():ge("3.15") then
                 table.join2(argv, targets)
             else
                 raise("Build multiple targets need cmake >=3.15")
@@ -1168,7 +1166,7 @@ function _install_for_ninja(package, configs, opt)
     _fix_pdbdir_for_ninja(package)
     ninja.install(package, {}, {envs = opt.envs or buildenvs(package, opt),
         jobs = opt.jobs,
-        target = opt.target})
+        targets = opt.targets or opt.target})
 end
 
 -- do install for cmake/build
@@ -1176,12 +1174,15 @@ function _install_for_cmakebuild(package, configs, opt)
     opt = opt or {}
     local cmake = assert(find_tool("cmake"), "cmake not found!")
     local argv = {"--build", os.curdir()}
+    local install_argv = {"--install", os.curdir()}
     if opt.config then
         table.insert(argv, "--config")
         table.insert(argv, opt.config)
+        table.insert(install_argv, "--config")
+        table.insert(install_argv, opt.config)
     end
     os.vrunv(cmake.program, argv, {envs = opt.envs or buildenvs(package)})
-    os.vrunv(cmake.program, {"--install", os.curdir()})
+    os.vrunv(cmake.program, install_argv)
 end
 
 -- get cmake generator
@@ -1244,7 +1245,7 @@ function _shrink_cmake_arguments(argv, oldir, opt)
     local shrink = false
     local add_compile_options = false
     local add_link_options = false
-    if _get_cmake_version():ge("3.13") then
+    if _get_cmake_version() and _get_cmake_version():ge("3.13") then
         add_compile_options = true
         add_link_options = true
     end
@@ -1294,7 +1295,7 @@ end
 
 function configure(package, configs, opt)
     opt = opt or {}
-    local oldir = _enter_buildir(package, opt)
+    local oldir = _enter_builddir(package, opt)
 
     -- pass configurations
     local argv = {}
@@ -1328,7 +1329,7 @@ function build(package, configs, opt)
     configure(package, configs, opt)
 
     -- do build
-    local oldir = _enter_buildir(package, opt)
+    local oldir = _enter_builddir(package, opt)
     if opt.cmake_build then
         _build_for_cmakebuild(package, configs, opt)
     elseif cmake_generator then
@@ -1360,7 +1361,7 @@ function install(package, configs, opt)
     configure(package, configs, opt)
 
     -- do build and install
-    local oldir = _enter_buildir(package, opt)
+    local oldir = _enter_builddir(package, opt)
     if opt.cmake_build then
         _install_for_cmakebuild(package, configs, opt)
     elseif cmake_generator then
