@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        main.lua
@@ -52,7 +52,7 @@ end
 function _load_package(package)
 
     -- ensure build and output directories
-    os.tryrm(package:buildir())
+    os.tryrm(package:builddir())
     os.mkdir(package:outputdir())
 
     -- load it
