@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        makefile.lua
@@ -27,8 +27,8 @@ import("core.language.language")
 import("core.platform.platform")
 import("lib.detect.find_tool")
 import("private.utils.batchcmds")
-import("private.utils.rule_groups")
 import("plugins.project.utils.target_cmds", {rootdir = os.programdir()})
+import("private.utils.target", {alias = "target_utils"})
 
 -- tranlate path
 function _translate_path(filepath, outputdir)
@@ -267,8 +267,9 @@ function _get_command_string(cmd, outputdir)
         return _get_cmd_cd(_get_relative_unix_path(cmd.dir, outputdir))
     elseif kind == "mkdir" then
         return _get_cmd_mkdir(_get_relative_unix_path(cmd.dir, outputdir))
-    elseif kind == "show" then
-        return _get_cmd_echo(cmd.showtext)
+    elseif kind == "show" or kind == "show_progress" then
+        local text = string.format(cmd.format, table.unpack(cmd.argv))
+        return _get_cmd_echo(text)
     end
 end
 
@@ -334,8 +335,9 @@ function _add_toolchains(makefile, outputdir)
     makefile:print("")
 
     -- add toolchains from targets
-    for targetname, target in pairs(project.targets()) do
-        if not target:is_phony() then
+    local project_targets = target_utils.get_project_targets()
+    for targetname, target in pairs(project_targets) do
+        if not _phony_or_headeronly(target) then
             local program = _get_program_from_target(target, target:linker():kind())
             if program then
                 makefile:print("%s_%s=%s", targetname, target:linker():kind():upper(), program)
@@ -354,10 +356,15 @@ function _add_toolchains(makefile, outputdir)
     makefile:print("")
 end
 
+function _phony_or_headeronly(target) 
+    return target:is_phony() or target:is_headeronly()
+end
+
 -- add flags
 function _add_flags(makefile, targetflags, outputdir)
-    for targetname, target in pairs(project.targets()) do
-        if not target:is_phony() then
+    local project_targets = target_utils.get_project_targets()
+    for targetname, target in pairs(project_targets) do
+        if not _phony_or_headeronly(target) then
             for _, sourcebatch in pairs(target:sourcebatches()) do
                 local sourcekind = sourcebatch.sourcekind
                 if sourcekind then
@@ -469,14 +476,11 @@ function _add_build_phony(makefile, target)
 end
 
 -- add custom commands before building target
-function _add_build_custom_commands_before(makefile, target, sourcegroups, outputdir)
+function _add_build_custom_commands_before(makefile, target, outputdir)
 
     -- add before commands
     -- we use irpairs(groups), because the last group that should be given the highest priority.
-    local cmds_before = {}
-    target_cmds.get_target_buildcmd(target, cmds_before, {suffix = "before"})
-    target_cmds.get_target_buildcmd_sourcegroups(target, cmds_before, sourcegroups, {suffix = "before"})
-    target_cmds.get_target_buildcmd_sourcegroups(target, cmds_before, sourcegroups)
+    local cmds_before = target_cmds.get_target_buildcmds(target, {stages = {"before", "on"}})
 
     local targetname = target:name()
     local label = "precmds_" .. targetname
@@ -494,10 +498,8 @@ function _add_build_custom_commands_before(makefile, target, sourcegroups, outpu
 end
 
 -- add custom commands after building target
-function _add_build_custom_commands_after(makefile, target, sourcegroups, outputdir)
-    local cmds_after = {}
-    target_cmds.get_target_buildcmd_sourcegroups(target, cmds_after, sourcegroups, {suffix = "after"})
-    target_cmds.get_target_buildcmd(target, cmds_after, {suffix = "after"})
+function _add_build_custom_commands_after(makefile, target, outputdir)
+    local cmds_after = target_cmds.get_target_buildcmds(target, {stages = {"after"}})
     if #cmds_after > 0 then
         for _, cmd in ipairs(cmds_after) do
             local command = _get_command_string(cmd, outputdir)
@@ -514,14 +516,11 @@ function _add_build_target(makefile, target, targetflags, outputdir)
     -- https://github.com/xmake-io/xmake/issues/2337
     target:data_set("plugin.project.kind", "makefile")
 
-    -- build sourcebatch groups first
-    local sourcegroups = rule_groups.build_sourcebatch_groups(target, target:sourcebatches())
-
     -- add custom commands before building target
-    local precmds_label = _add_build_custom_commands_before(makefile, target, sourcegroups, outputdir)
+    local precmds_label = _add_build_custom_commands_before(makefile, target, outputdir)
 
     -- is phony target?
-    if target:is_phony() then
+    if _phony_or_headeronly(target) then
         return _add_build_phony(makefile, target)
     end
 
@@ -548,7 +547,7 @@ function _add_build_target(makefile, target, targetflags, outputdir)
     -- make dependence for the dependent targets
     for _, depname in ipairs(target:get("deps")) do
         local dep = project.target(depname, {namespace = target:namespace()})
-        makefile:write(" " .. (dep:is_phony() and depname or _get_relative_unix_path(dep:targetfile(), outputdir)))
+        makefile:write(" " .. (_phony_or_headeronly(dep) and depname or _get_relative_unix_path(dep:targetfile(), outputdir)))
     end
 
     -- make dependence for objects
@@ -602,7 +601,7 @@ function _add_build_target(makefile, target, targetflags, outputdir)
     makefile:writef("\t$(VV)%s\n", command)
 
     -- add custom commands after building target
-    _add_build_custom_commands_after(makefile, target, sourcegroups, outputdir)
+    _add_build_custom_commands_after(makefile, target, outputdir)
 
     -- end
     makefile:print("")
@@ -621,19 +620,20 @@ end
 -- add build targets
 function _add_build_targets(makefile, targetflags, outputdir)
     local default = ""
-    for targetname, target in pairs(project.targets()) do
+    local project_targets = target_utils.get_project_targets()
+    for targetname, target in pairs(project_targets) do
         if target:is_default() then
             default = default .. " " .. targetname
         end
     end
     makefile:print("default: %s\n", default)
     local all = ""
-    for targetname, _ in pairs(project.targets()) do
+    for targetname, _ in pairs(project_targets) do
         all = all .. " " .. targetname
     end
     makefile:print("all: %s\n", all)
     makefile:print(".PHONY: default all %s\n", all)
-    for _, target in pairs(project.targets()) do
+    for _, target in pairs(project_targets) do
         _add_build_target(makefile, target, targetflags, outputdir)
     end
 end
@@ -643,7 +643,8 @@ function _add_build(makefile, targetflags, outputdir)
 
     -- TODO
     -- disable precompiled header first
-    for _, target in pairs(project.targets()) do
+    local project_targets = target_utils.get_project_targets()
+    for _, target in pairs(project_targets) do
         target:set("pcheader", nil)
         target:set("pcxxheader", nil)
     end
@@ -659,7 +660,7 @@ function _add_clean_target(makefile, target, outputdir)
         makefile:write(" clean_" .. dep)
     end
     makefile:print("")
-    if not target:is_phony() then
+    if not _phony_or_headeronly(target) then
         _add_remove_files(makefile, target:targetfile(), outputdir)
         _add_remove_files(makefile, target:symbolfile(), outputdir)
         _add_remove_files(makefile, target:objectfiles(), outputdir)
@@ -670,13 +671,14 @@ end
 -- add clean targets
 function _add_clean_targets(makefile, outputdir)
     local all = ""
-    for targetname, _ in pairs(project.targets()) do
+    local project_targets = target_utils.get_project_targets()
+    for targetname, _ in pairs(project_targets) do
         all = all .. " clean_" .. targetname
     end
     makefile:print("clean: %s\n", all)
 
     -- add clean targets
-    for _, target in pairs(project.targets()) do
+    for _, target in pairs(project_targets) do
         _add_clean_target(makefile, target, outputdir)
     end
 end
@@ -687,10 +689,11 @@ function _add_clean(makefile, outputdir)
 end
 
 function make(outputdir)
-
-    -- enter project directory
     local oldir = os.cd(os.projectdir())
 
+    -- prepare targets
+    target_cmds.prepare_targets()
+
     -- open the makefile
     local makefile = io.open(path.join(outputdir, "makefile"), "w")
 
@@ -715,7 +718,5 @@ function make(outputdir)
 
     -- close the makefile
     makefile:close()
-
-    -- leave project directory
     os.cd(oldir)
 end
