@@ -79,6 +79,16 @@ function get_target_buildcmds(target, opt)
             end
         end
     end
+    -- translate batchcmds:lua to batchcmds:runv, we need to generate executable commmand
+    for _, cmd in ipairs(buildcmds:cmds()) do
+        local kind = cmd.kind
+        if cmd.script and (kind == "lua" or kind == "vlua") then
+            cmd.kind = (kind == "vlua") and "vrunv" or "runv"
+            cmd.program = os.programfile()
+            cmd.argv = table.join("lua", cmd.script, cmd.argv)
+            cmd.script = nil
+        end
+    end
     return buildcmds:cmds()
 end
 
