@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        xmake.lua
@@ -20,5 +20,5 @@
 
 -- define rule: utils.inherit.links
 rule("utils.inherit.links")
-    on_config("inherit_links")
+    after_config("inherit_links")
 
