@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        verilator.lua
@@ -207,7 +207,7 @@ endmodule]])
     os.rm(tmpdir)
 end
 
-function build_cppfiles(target, batchjobs, sourcebatch, opt)
+function build_cppfiles(target, jobgraph, sourcebatch, opt)
     local toolchain = assert(target:toolchain("verilator"), 'we need to set_toolchains("verilator") in target("%s")', target:name())
     local verilator = assert(toolchain:config("verilator"), "verilator not found!")
     local autogendir = path.join(target:autogendir(), "rules", "verilator")
@@ -256,12 +256,12 @@ function build_cppfiles(target, batchjobs, sourcebatch, opt)
         dependfiles = {}}
     for _, sourcefile in ipairs(sourcefiles) do
         local objectfile = target:objectfile(sourcefile)
-        local dependfile = target:objectfile(objectfile)
+        local dependfile = target:dependfile(objectfile)
         table.insert(target:objectfiles(), objectfile)
         table.insert(sourcebatch_cpp.objectfiles, objectfile)
         table.insert(sourcebatch_cpp.dependfiles, dependfile)
     end
-    build_objectfiles(target, batchjobs, sourcebatch_cpp, opt)
+    build_objectfiles(target, jobgraph, sourcebatch_cpp, opt)
 end
 
 function buildcmd_vfiles(target, batchcmds, sourcebatch, opt)
