@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        xmake.lua
@@ -54,8 +54,8 @@ rule("xmake.cli")
         local headerdir = path.join(target:autogendir(), "rules", "xmake.cli", "include")
         local headerfile = path.join(headerdir, "luafiles.xmz.h")
         target:add("includedirs", headerdir)
-        argv = {"lua", "private.utils.bin2c", "--nozeroend", "-i", path(archivefile), "-o", path(headerfile)}
-        batchcmds:vrunv(os.programfile(), argv, {envs = {XMAKE_SKIP_HISTORY = "y"}})
+        argv = {"--nozeroend", "-i", path(archivefile), "-o", path(headerfile)}
+        batchcmds:vlua("private.utils.bin2c", argv)
 
         batchcmds:add_depfiles(sourcefiles)
         batchcmds:set_depmtime(os.mtime(dependfile))
