@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        check.lua
@@ -28,6 +28,14 @@ import("detect.sdks.find_cross_toolchain")
 -- find xcode on macos
 function _find_xcode(toolchain)
 
+    -- get apple device
+    local appledev = toolchain:config("appledev") or config.get("appledev")
+    if appledev and appledev == "simulator" then
+        appledev = "simulator"
+    elseif not toolchain:is_plat("macosx") and toolchain:is_arch("i386", "x86_64") then
+        appledev = "simulator"
+    end
+
     -- find xcode
     local xcode_sdkver = toolchain:config("xcode_sdkver") or config.get("xcode_sdkver")
     local xcode = find_xcode(toolchain:config("xcode") or config.get("xcode"), {force = true, verbose = true,
@@ -46,9 +54,14 @@ function _find_xcode(toolchain)
         config.set("xcode", xcode.sdkdir, {force = true, readonly = true})
         cprint("checking for Xcode directory ... ${color.success}%s", xcode.sdkdir)
     end
+    local target_minver = toolchain:config("target_minver") or config.get("target_minver")
+    if xcode_sdkver and not target_minver then
+        target_minver = xcode.target_minver
+    end
     toolchain:config_set("xcode", xcode.sdkdir)
     toolchain:config_set("xcode_sdkver", xcode_sdkver)
-    toolchain:configs_save()
+    toolchain:config_set("target_minver", target_minver)
+    toolchain:config_set("appledev", appledev)
     cprint("checking for SDK version of Xcode for %s (%s) ... ${color.success}%s", toolchain:plat(), toolchain:arch(), xcode_sdkver)
 end
 
@@ -84,7 +97,7 @@ function main(toolchain)
     end
 
     -- find cross toolchain from external envirnoment
-    local cross_toolchain = find_cross_toolchain(sdkdir, {bindir = bindir, cross = cross})
+    local cross_toolchain = find_cross_toolchain(sdkdir, {bindir = bindir})
     if not cross_toolchain then
         -- find it from packages
         for _, package in ipairs(toolchain:packages()) do
@@ -98,10 +111,9 @@ function main(toolchain)
         end
     end
     if cross_toolchain then
-        toolchain:config_set("cross", cross_toolchain.cross)
+        toolchain:config_set("cross", cross)
         toolchain:config_set("bindir", cross_toolchain.bindir)
         toolchain:config_set("sdkdir", cross_toolchain.sdkdir)
-        toolchain:configs_save()
     else
         raise("llvm toolchain not found!")
     end
@@ -116,3 +128,4 @@ function main(toolchain)
     end
     return cross_toolchain
 end
+
