@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        load.lua
@@ -85,16 +85,25 @@ function main(toolchain)
     local ndk_sdkver = toolchain:config("ndk_sdkver")
 
     -- set toolset
-    toolchain:set("toolset", "cc", "clang", cross .. "gcc")
-    toolchain:set("toolset", "cxx", "clang++", cross .. "g++")
-    toolchain:set("toolset", "cpp", "clang -E", cross .. "gcc -E")
-    toolchain:set("toolset", "as", "clang", cross .. "gcc")
-    toolchain:set("toolset", "ld", "clang++", "clang", cross .. "g++", cross .. "gcc")
-    toolchain:set("toolset", "sh", "clang++", "clang", cross .. "g++", cross .. "gcc")
+    local use_gcc = toolchain:config("gcc")
+    if use_gcc then
+        toolchain:set("toolset", "cc", cross .. "gcc")
+        toolchain:set("toolset", "cxx", cross .. "g++")
+        toolchain:set("toolset", "cpp", cross .. "gcc -E")
+        toolchain:set("toolset", "as", cross .. "gcc")
+        toolchain:set("toolset", "ld", cross .. "g++", cross .. "gcc")
+        toolchain:set("toolset", "sh", cross .. "g++", cross .. "gcc")
+    else
+        toolchain:set("toolset", "cc", "clang", cross .. "gcc")
+        toolchain:set("toolset", "cxx", "clang++", cross .. "g++")
+        toolchain:set("toolset", "cpp", "clang -E", cross .. "gcc -E")
+        toolchain:set("toolset", "as", "clang", cross .. "gcc")
+        toolchain:set("toolset", "ld", "clang++", "clang", cross .. "g++", cross .. "gcc")
+        toolchain:set("toolset", "sh", "clang++", "clang", cross .. "g++", cross .. "gcc")
+    end
     toolchain:set("toolset", "ar", gcc_toolchain_bin and path.join(gcc_toolchain_bin, cross .. "ar") or (cross .. "ar"), "llvm-ar")
     toolchain:set("toolset", "ranlib", gcc_toolchain_bin and path.join(gcc_toolchain_bin, cross .. "ranlib") or (cross .. "ranlib"))
     toolchain:set("toolset", "strip", gcc_toolchain_bin and path.join(gcc_toolchain_bin, cross .. "strip") or (cross .. "strip"), "llvm-strip")
-
     -- gnustl and stlport have been removed in ndk r18 (deprecated in ndk r17)
     -- https://github.com/android/ndk/wiki/Changelog-r18
     local old_runtimes = {"gnustl_static", "gnustl_shared", "stlport_static", "stlport_shared"}
@@ -174,6 +183,7 @@ function main(toolchain)
         local sysroot_arch = sysroot_archs[arch]
 
         -- add sysroot flags
+        local sysroot_cflags_added = false
         local ndk_sysroot = toolchain:config("ndk_sysroot")
         if ndk_sysroot and os.isdir(ndk_sysroot) then
             local triple = _get_triple(arch)
@@ -189,17 +199,21 @@ function main(toolchain)
             toolchain:add("cflags",   flag_isystem)
             toolchain:add("cxxflags", flag_isystem)
             toolchain:add("asflags",  flag_isystem)
-        else
-            local ndk_sdkdir = path.translate(format("%s/platforms/android-%d", ndk, ndk_sdkver))
-            if os.isdir(ndk_sdkdir) then
-                if sysroot_arch then
-                    local flag_sysroot = "--sysroot=" .. os.args(path.join(ndk_sdkdir, sysroot_arch))
+            sysroot_cflags_added = true
+        end
+        local ndk_sdkdir = path.translate(format("%s/platforms/android-%d", ndk, ndk_sdkver))
+        if os.isdir(ndk_sdkdir) then
+            if sysroot_arch then
+                local flag_sysroot = "--sysroot=" .. os.args(path.join(ndk_sdkdir, sysroot_arch))
+                if not sysroot_cflags_added then
                     toolchain:add("cflags",   flag_sysroot)
                     toolchain:add("cxxflags", flag_sysroot)
                     toolchain:add("asflags",  flag_sysroot)
-                    toolchain:add("ldflags",  flag_sysroot)
-                    toolchain:add("shflags",  flag_sysroot)
                 end
+                -- we need to add sysroot flags for low-version ndk
+                -- @see https://github.com/xmake-io/xmake/issues/6621
+                toolchain:add("ldflags",  flag_sysroot)
+                toolchain:add("shflags",  flag_sysroot)
             end
         end
 
@@ -372,8 +386,10 @@ function main(toolchain)
         table.insert(rcshflags, "-l" .. link)
         table.insert(rcldflags, "-l" .. link)
     end
-    toolchain:add("rcshflags", "-C link-args=\"" .. (table.concat(rcshflags, " "):gsub("%-march=.-%s", "") .. "\""))
-    toolchain:add("rcldflags", "-C link-args=\"" .. (table.concat(rcldflags, " "):gsub("%-march=.-%s", "") .. "\""))
+    -- fix [[note: clang++: error: no such file or directory: '"-llog']] on windows
+    -- @note 'link-args=...' should not be 'link-args="..."'
+    toolchain:set("rcshflags", {"-C", "link-args=" .. (table.concat(rcshflags, " "):gsub("%-march=.-%s", ""))}, {expand = false})
+    toolchain:set("rcldflags", {"-C", "link-args=" .. (table.concat(rcldflags, " "):gsub("%-march=.-%s", ""))}, {expand = false})
     local sh = toolchain:tool("sh") -- @note we cannot use `config.get("sh")`, because we need to check sh first
     if sh then
         toolchain:add("rcshflags", "-C linker=" .. sh)
